/*
 *******************************************************************************
 *
 *  Copyright 2025 RIEGL Laser Measurement Systems
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 *  SPDX-License-Identifier: Apache-2.0
 *
 *******************************************************************************
 */
/*!
 *******************************************************************************
 *
 * \author  RIEGL LMS GmbH, Austria
 * \brief   Description of RIEGL RDB 2 database meta data items.
 * \version 2015-10-27/AW: Initial version
 * \version 2015-11-25/AW: Item "Geo Tag" added
 * \version 2016-10-27/AW: Item "Voxel Information" added
 * \version 2016-11-17/AW: Item "Voxel Information" updated
 * \version 2016-12-12/AW: Item "Range Statistics" added
 * \version 2017-03-08/AW: Item "Plane Patch Statistics" added
 * \version 2017-04-05/AW: Items "Atmosphere" and "Geometric Scale Factor" added
 * \version 2017-08-22/AW: Items for waveform sample block and value files added
 * \version 2017-10-24/AW: Item "Gaussian Decomposition" added
 * \version 2017-11-13/AW: Item "riegl.scan_pattern" updated
 * \version 2017-11-21/AW: Item "riegl.trajectory_info" added
 * \version 2018-01-11/AW: Item "riegl.beam_geometry" added
 * \version 2018-01-15/AW: Item "riegl.reflectance_calculation" added
 * \version 2018-01-15/AW: Item "riegl.near_range_correction" added
 * \version 2018-01-15/AW: Item "riegl.device_geometry" added
 * \version 2018-02-13/AW: Item "riegl.notch_filter" added
 * \version 2018-03-08/AW: Item "riegl.window_echo_correction" added
 * \version 2018-03-15/AW: Item "riegl.pulse_position_modulation" added
 * \version 2018-05-24/AW: Item "riegl.pixel_info" added
 * \version 2018-06-08/AW: Item "riegl.shot_info" added
 * \version 2018-06-08/AW: Item "riegl.echo_info" added
 * \version 2018-06-14/AW: Item "riegl.mta_settings" added
 * \version 2018-06-14/AW: Item "riegl.receiver_internals" added
 * \version 2018-06-14/AW: Item "riegl.device_output_limits" added
 * \version 2018-06-26/AW: Schema: replace "number" with "integer" if applicable
 * \version 2018-07-09/AW: Item "riegl.pose_estimation" added
 * \version 2018-07-09/AW: Item "riegl.pose_sensors" added
 * \version 2018-09-20/AW: Item "riegl.pointcloud_info" added
 * \version 2018-11-08/AW: Item "riegl.scan_pattern" updated
 * \version 2018-11-13/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-06/AW: Item "riegl.receiver_internals" updated
 * \version 2019-03-21/AW: Item "riegl.device_geometry" updated
 * \version 2019-04-15/AW: Item "riegl.point_attribute_groups" added
 * \version 2019-04-30/AW: Item "riegl.waveform_settings" added
 * \version 2019-10-03/AW: Item "riegl.angular_notch_filter" added
 * \version 2019-10-03/AW: Item "riegl.noise_estimates" added
 * \version 2019-10-25/AW: Item "riegl.window_analysis" added
 * \version 2019-11-06/AW: Item "riegl.georeferencing_parameters" added
 * \version 2019-11-27/AW: Item "riegl.plane_patch_matching" added
 * \version 2019-12-13/AW: Items for tie-/control objects added
 * \version 2019-12-19/AW: Items for tie-/control objects added
 * \version 2020-02-04/AW: Item "riegl.detection_probability" added
 * \version 2020-02-04/AW: Item "riegl.licenses" added
 * \version 2020-04-27/AW: Item "riegl.waveform_info" updated (schema+example)
 * \version 2020-09-03/AW: Item "riegl.reflectance_correction" added
 * \version 2020-09-10/AW: Item "riegl.device_geometry_passive_channel" added
 * \version 2020-09-25/AW: Item "riegl.georeferencing_parameters" updated
 * \version 2020-09-25/AW: Item "riegl.trajectory_info" updated
 * \version 2020-09-29/AW: Item "riegl.temperature_calculation" added
 * \version 2020-10-23/AW: Item "riegl.exponential_decomposition" added (#3709)
 * \version 2020-11-30/AW: Item "riegl.notch_filter" updated (schema)
 * \version 2020-12-02/AW: Item "riegl.georeferencing_parameters" updated (schema)
 * \version 2021-02-02/AW: Item "riegl.plane_slope_class_info" added (rdbplanes/#7)
 * \version 2021-02-16/AW: Item "riegl.device_output_limits" updated (schema, #3811)
 * \version 2021-03-03/AW: Item "riegl.exponential_decomposition" updated (schema, #3822)
 * \version 2021-03-03/AW: Item "riegl.waveform_averaging_settings" added (#3821)
 * \version 2021-04-01/AW: Item "riegl.voxel_info" updated (schema, #3854)
 * \version 2021-04-16/AW: Item "riegl.voxel_info" updated (schema, #3866)
 * \version 2021-09-30/AW: Item "riegl.waveform_info" updated (schema+example, #4016)
 * \version 2021-10-04/AW: Improved spelling of the descriptions of some items
 * \version 2021-11-04/AW: Rename "riegl.record_names" to "riegl.item_names" (#4034)
 * \version 2022-03-11/AW: Item "riegl.devices" added (#4162)
 * \version 2022-03-14/AW: Item "riegl.stored_filters" added (#4164)
 * \version 2022-09-20/AW: Fix typos in schema of "riegl.georeferencing_parameters"
 * \version 2022-09-30/AW: Item "riegl.system_description" added (#4368)
 * \version 2022-10-10/AW: Correction of typos in the titles of some entries
 * \version 2022-10-20/AW: Item "riegl.stored_filters" updated (example, #4164)
 * \version 2023-01-19/AW: Item "riegl.ttip_configuration" added (#4449)
 * \version 2024-09-26/AW: Item "riegl.dyntrig" added (#5310)
 *
 *******************************************************************************
 */

#ifndef RDB_354CFFB3_BDAA_4E38_98C8_9C09D0C0AD87
#define RDB_354CFFB3_BDAA_4E38_98C8_9C09D0C0AD87

#include <vector>
#include <string>
#include <cstdlib>
#include <cstdint>

namespace riegl {
namespace rdb {
namespace pointcloud {

// Meta data item definition version
const std::string RDB_META_DATA_ITEMS_VERSION = "1.1.54";
const std::string RDB_META_DATA_ITEMS_DATE = "2023-01-19";

// Meta data item states
const unsigned char RDB_STATUS_REQUIRED = 1; // mandatory item
const unsigned char RDB_STATUS_OPTIONAL = 2; // optional item

// Container record for meta data item details
struct MetaDataItemInfo
{
    std::string   name;
    std::string   title;
    std::string   description;
    unsigned char status;
    std::string   schema;
    std::string   example;

    operator const std::string&() const { return name; }
};

// Angular notch filter parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_ANGULAR_NOTCH_FILTER = {
    /* name        */ "riegl.angular_notch_filter",
    /* title       */ "Angular Notch Filter",
    /* description */ "Angular notch filter parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Angular Notch Filter\",\"$schema\":\"http://json"
    "-schema.org/draft-04/schema#\",\"description\":\"Angular notch filter "
    "parameters for window glass echoes\",\"properties\":{\"amplitude_mean\":{\"t"
    "ype\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"Mean amplitude ["
    "dB]\"},\"range_mean\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"descript"
    "ion\":\"Mean range [m]\"},\"angle\":{\"type\":\"array\",\"items\":{\"type\":\"number"
    "\"},\"description\":\"Angle "
    "[deg]\"}},\"required\":[\"angle\",\"range_mean\",\"amplitude_mean\"]}"
    ,
    /* example: */
    "{\"amplitude_mean\":[3.780913,3.780913,3.480913,3.120913,2.850913,2.7209"
    "13,2.680913,2.610913,2.530913,2.570913,2.570913],\"range_mean\":[0.094,0"
    ".094,0.09075,0.08675,0.0815,0.0775,0.074,0.071,0.068,0.0675,0.06475],\""
    "angle\":[14.0,15.0,16.0,17.0,18.0,19.0,20.0,21.0,22.0,23.0,24.0]}"
};

// Atmospheric parameters
const MetaDataItemInfo RDB_RIEGL_ATMOSPHERE = {
    /* name        */ "riegl.atmosphere",
    /* title       */ "Atmosphere",
    /* description */ "Atmospheric parameters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Atmospheric Parameters\",\"$schema\":\"http://js"
    "on-schema.org/draft-04/schema#\",\"description\":\"Atmospheric parameters\""
    ",\"properties\":{\"attenuation\":{\"type\":\"number\",\"description\":\"Atmospher"
    "ic attenuation "
    "[1/km]\"},\"pressure\":{\"type\":\"number\",\"description\":\"Pressure along "
    "measurment path "
    "[mbar]\"},\"group_velocity\":{\"type\":\"number\",\"description\":\"Group "
    "velocity of laser beam "
    "[m/s]\"},\"pressure_sl\":{\"type\":\"number\",\"description\":\"Atmospheric "
    "pressure at sea level "
    "[mbar]\"},\"rel_humidity\":{\"type\":\"number\",\"description\":\"Relative "
    "humidity along measurement path "
    "[%]\"},\"temperature\":{\"type\":\"number\",\"description\":\"Temperature along "
    "measurement path "
    "[\\u00b0C]\"},\"amsl\":{\"type\":\"number\",\"description\":\"Height above mean "
    "sea level (AMSL) "
    "[m]\"},\"wavelength\":{\"type\":\"number\",\"description\":\"Laser wavelength [n"
    "m]\"}},\"required\":[\"temperature\",\"pressure\",\"rel_humidity\",\"pressure_sl"
    "\",\"amsl\",\"group_velocity\",\"attenuation\",\"wavelength\"]}"
    ,
    /* example: */
    "{\"attenuation\":0.028125,\"pressure\":970,\"group_velocity\":299711000.0,\"p"
    "ressure_sl\":970,\"rel_humidity\":63,\"temperature\":7,\"amsl\":0,\"wavelength"
    "\":1550}"
};

// Laser beam geometry details
const MetaDataItemInfo RDB_RIEGL_BEAM_GEOMETRY = {
    /* name        */ "riegl.beam_geometry",
    /* title       */ "Beam Geometry",
    /* description */ "Laser beam geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Beam Geometry\",\"$schema\":\"http://json-schema"
    ".org/draft-04/schema#\",\"description\":\"Laser beam geometry details\",\"pr"
    "operties\":{\"beam_exit_diameter\":{\"type\":\"number\",\"exclusiveMinimum\":fa"
    "lse,\"minimum\":0,\"description\":\"Beam width at exit aperture [m]\"},\"beam"
    "_divergence\":{\"type\":\"number\",\"exclusiveMinimum\":false,\"minimum\":0,\"de"
    "scription\":\"Beam divergence in far field "
    "[rad]\"}},\"required\":[\"beam_exit_diameter\",\"beam_divergence\"]}"
    ,
    /* example: */
    "{\"beam_exit_diameter\":0.0072,\"beam_divergence\":0.0003}"
};

// List of control object type definitions
const MetaDataItemInfo RDB_RIEGL_CONTROL_OBJECT_CATALOG = {
    /* name        */ "riegl.control_object_catalog",
    /* title       */ "Control Object Catalog",
    /* description */ "List of control object type definitions",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"definitions\":{\"checkerboard2x2\":{\"type\":\"object\",\"al"
    "lOf\":[{\"$ref\":\"#/definitions/common\"},{\"type\":\"object\",\"properties\":{\""
    "square_length\":{\"type\":\"number\",\"exclusiveMinimum\":true,\"minimum\":0,\"d"
    "escription\":\"length of a square of the checkerboard in meters\"},\"shape"
    "\":{\"type\":\"string\",\"enum\":[\"checkerboard2x2\"],\"description\":\"shape ide"
    "ntifier\"}},\"required\":[\"shape\",\"square_length\"],\"description\":\"checker"
    "board specific properties\"}],\"description\":\"checkerboard 2 by 2\"},\"sph"
    "ere\":{\"type\":\"object\",\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"type\""
    ":\"object\",\"properties\":{\"shape\":{\"type\":\"string\",\"enum\":[\"sphere\"],\"de"
    "scription\":\"shape identifier\"},\"diameter\":{\"type\":\"number\",\"exclusiveM"
    "inimum\":true,\"minimum\":0,\"description\":\"diameter in "
    "meters\"}},\"required\":[\"shape\",\"diameter\"],\"description\":\"sphere "
    "specific properties\"}],\"description\":\"sphere\"},\"chevron\":{\"type\":\"obje"
    "ct\",\"allOf\":[{\"$ref\":\"#/definitions/common\"},{\"type\":\"object\",\"propert"
    "ies\":{\"outside_edge_length\":{\"type\":\"number\",\"exclusiveMinimum\":true,\""
    "minimum\":0,\"description\":\"length of the two outer edges in meters\"},\"s"
    "hape\":{\"type\":\"string\",\"enum\":[\"chevron\"],\"description\":\"shape identif"
    "ier\"},\"thickness\":{\"type\":\"number\",\"exclusiveMinimum\":true,\"minimum\":0"
    ",\"description\":\"thickness in meters\"}},\"required\":[\"shape\",\"outside_ed"
    "ge_length\",\"thickness\"],\"description\":\"chevron specific properties\"}],"
    "\"description\":\"chevron\"},\"circular_disk\":{\"type\":\"object\",\"allOf\":[{\"$"
    "ref\":\"#/definitions/common\"},{\"type\":\"object\",\"properties\":{\"shape\":{\""
    "type\":\"string\",\"enum\":[\"circular_disk\"],\"description\":\"shape "
    "identifier\"},\"offset\":{\"type\":\"number\",\"description\":\"offset in "
    "meters, e.g. reflector constant (optional)\"},\"diameter\":{\"type\":\"numbe"
    "r\",\"exclusiveMinimum\":true,\"minimum\":0,\"description\":\"diameter in "
    "meters\"}},\"required\":[\"shape\",\"diameter\"],\"description\":\"circular disk"
    " specific properties\"}],\"description\":\"circular disk\"},\"round_corner_c"
    "ube_prism\":{\"type\":\"object\",\"allOf\":[{\"$ref\":\"#/definitions/common\"},{"
    "\"type\":\"object\",\"properties\":{\"shape\":{\"type\":\"string\",\"enum\":[\"round_"
    "corner_cube_prism\"],\"description\":\"shape "
    "identifier\"},\"offset\":{\"type\":\"number\",\"description\":\"offset in "
    "meters, e.g. reflector constant (optional)\"},\"diameter\":{\"type\":\"numbe"
    "r\",\"exclusiveMinimum\":true,\"minimum\":0,\"description\":\"diameter in "
    "meters\"}},\"required\":[\"shape\",\"diameter\"],\"description\":\"round corner "
    "cube prism specific properties\"}],\"description\":\"round corner cube pri"
    "sm\"},\"rectangle\":{\"type\":\"object\",\"allOf\":[{\"$ref\":\"#/definitions/comm"
    "on\"},{\"type\":\"object\",\"properties\":{\"width\":{\"type\":\"number\",\"exclusiv"
    "eMinimum\":true,\"minimum\":0,\"description\":\"width in meters\"},\"length\":{"
    "\"type\":\"number\",\"exclusiveMinimum\":true,\"minimum\":0,\"description\":\"len"
    "gth in meters\"},\"shape\":{\"type\":\"string\",\"enum\":[\"rectangle\"]}},\"requi"
    "red\":[\"shape\",\"length\",\"width\"],\"description\":\"rectangle specific prop"
    "erties\"}],\"description\":\"rectangle\"},\"common\":{\"type\":\"object\",\"proper"
    "ties\":{\"name\":{\"type\":\"string\",\"minLength\":3,\"description\":\"unique "
    "type identifier\"},\"shape\":{\"type\":\"string\",\"enum\":[\"rectangle\",\"checke"
    "rboard2x2\",\"chevron\",\"circular_disk\",\"cylinder\",\"sphere\",\"round_corner"
    "_cube_prism\"],\"description\":\"shape identifier\"},\"surface_type\":{\"type\""
    ":\"string\",\"enum\":[\"retro_reflective_foil\",\"diffuse\"],\"description\":\"su"
    "rface material "
    "type\"},\"description\":{\"type\":\"string\",\"description\":\"string describing"
    " the object\"}},\"required\":[\"name\",\"shape\"],\"description\":\"common "
    "object properties\"},\"cylinder\":{\"type\":\"object\",\"allOf\":[{\"$ref\":\"#/de"
    "finitions/common\"},{\"type\":\"object\",\"properties\":{\"shape\":{\"type\":\"str"
    "ing\",\"enum\":[\"cylinder\"],\"description\":\"shape identifier\"},\"height\":{\""
    "type\":\"number\",\"exclusiveMinimum\":true,\"minimum\":0,\"description\":\"heig"
    "ht in meters\"},\"diameter\":{\"type\":\"number\",\"exclusiveMinimum\":true,\"mi"
    "nimum\":0,\"description\":\"diameter in meters\"}},\"required\":[\"shape\",\"dia"
    "meter\",\"height\"],\"description\":\"cylinder specific properties\"}],\"descr"
    "iption\":\"cylinder\"}},\"$schema\":\"http://json-schema.org/draft-04/schema"
    "#\",\"description\":\"List of control object type "
    "definitions\",\"title\":\"Control Object Catalog\",\"properties\":{\"types\":{\""
    "type\":\"array\",\"uniqueItems\":true,\"items\":{\"type\":\"object\",\"oneOf\":[{\"$"
    "ref\":\"#/definitions/rectangle\"},{\"$ref\":\"#/definitions/checkerboard2x2"
    "\"},{\"$ref\":\"#/definitions/chevron\"},{\"$ref\":\"#/definitions/circular_di"
    "sk\"},{\"$ref\":\"#/definitions/cylinder\"},{\"$ref\":\"#/definitions/sphere\"}"
    ",{\"$ref\":\"#/definitions/round_corner_cube_prism\"}]}}},\"required\":[\"typ"
    "es\"]}"
    ,
    /* example: */
    "{\"comments\":[\"This file contains a list of control object types (aka. "
    "'catalog').\",\"Each type is described by an object,\",\"which must "
    "contain at least the following parameters:\",\"  - name: unique "
    "identifier of the type\",\"  - shape: one of the following supported "
    "shapes:\",\"      - rectangle\",\"      - checkerboard2x2\",\"      - "
    "chevron\",\"      - circular_disk\",\"      - cylinder\",\"      - sphere\",\""
    "      - round_corner_cube_prism\",\"Depending on 'shape', the following "
    "parameters must/may be specified:\",\"  - rectangle:\",\"      - length: "
    "length in meters\",\"      - width: width in meters\",\"  - "
    "checkerboard2x2:\",\"      - square_length: length of a square of the "
    "checkerboard in meters\",\"  - circular_disk:\",\"      - diameter: "
    "diameter in meters\",\"      - offset: offset in meters, e.g. reflector "
    "constant (optional)\",\"  - chevron:\",\"      - outside_edge_length: "
    "length of the two outer edges in meters\",\"      - thickness: thickness"
    " in meters\",\"  - cylinder:\",\"      - diameter: diameter in meters\",\""
    "      - height: height in meters\",\"  - sphere:\",\"      - diameter: "
    "diameter in meters\",\"  - round_corner_cube_prism:\",\"      - diameter: "
    "diameter in meters\",\"      - offset: offset in meters, e.g. reflector "
    "constant (optional)\",\"Optional parameters:\",\"    - description: string"
    " describing the object\",\"    - surface_type: surface material type "
    "(either 'retro_reflective_foil' or "
    "'diffuse')\"],\"types\":[{\"width\":0.3,\"name\":\"Rectangle "
    "60x30\",\"length\":0.6,\"shape\":\"rectangle\",\"description\":\"Rectangle (60cm"
    " x 30cm)\"},{\"width\":0.4,\"name\":\"Rectangle "
    "80x40\",\"length\":0.8,\"shape\":\"rectangle\",\"description\":\"Rectangle (80cm"
    " x 40cm)\"},{\"square_length\":0.3,\"name\":\"Checkerboard2x2 "
    "30\",\"shape\":\"checkerboard2x2\",\"description\":\"Checkerboard (square "
    "length: 30cm)\"},{\"square_length\":0.5,\"name\":\"Checkerboard2x2 "
    "50\",\"shape\":\"checkerboard2x2\",\"description\":\"Checkerboard (square "
    "length: 50cm)\"},{\"outside_edge_length\":0.6096,\"name\":\"Chevron "
    "24''/4''\",\"shape\":\"chevron\",\"thickness\":0.1016,\"description\":\"Chevron "
    "(a=24''; b=4'')\"},{\"name\":\"Circular Disk 50\",\"diameter\":0.5,\"shape\":\"c"
    "ircular_disk\",\"surface_type\":\"diffuse\",\"description\":\" Circular Disk "
    "(diameter: "
    "50cm)\"},{\"surface_type\":\"retro_reflective_foil\",\"description\":\"flat "
    "circular reflector from retro-reflective foil\",\"name\":\"RIEGL flat "
    "reflector 50 mm\",\"shape\":\"circular_disk\",\"offset\":0.0,\"diameter\":0.05}"
    ",{\"surface_type\":\"retro_reflective_foil\",\"description\":\"flat circular "
    "reflector from retro-reflective foil\",\"name\":\"RIEGL flat reflector 100"
    " mm\",\"shape\":\"circular_disk\",\"offset\":0.0,\"diameter\":0.1},{\"surface_ty"
    "pe\":\"retro_reflective_foil\",\"description\":\"flat circular reflector "
    "from retro-reflective foil\",\"name\":\"RIEGL flat reflector 150 mm\",\"shap"
    "e\":\"circular_disk\",\"offset\":0.0,\"diameter\":0.15},{\"height\":0.05,\"descr"
    "iption\":\"cylindrical reflector from retro-reflective "
    "foil\",\"name\":\"RIEGL cylindrical reflector 50 mm\",\"shape\":\"cylinder\",\"s"
    "urface_type\":\"retro_reflective_foil\",\"diameter\":0.05},{\"height\":0.1,\"d"
    "escription\":\"cylindrical reflector from retro-reflective "
    "foil\",\"name\":\"RIEGL cylindrical reflector 100 mm\",\"shape\":\"cylinder\",\""
    "surface_type\":\"retro_reflective_foil\",\"diameter\":0.1},{\"name\":\"Sphere "
    "200 mm\",\"diameter\":0.2,\"shape\":\"sphere\",\"description\":\"Sphere "
    "(diameter: 200 mm)\"},{\"name\":\"Corner Cube Prism 50 mm\",\"diameter\":0.05"
    ",\"shape\":\"round_corner_cube_prism\",\"offset\":0.0,\"description\":\"round "
    "corner cube prism\"}]}"
};

// Details about the control object reference file
const MetaDataItemInfo RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE = {
    /* name        */ "riegl.control_object_reference_file",
    /* title       */ "Control Object Reference file",
    /* description */ "Details about the control object reference file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Control Object Reference file\",\"$schema\":\"ht"
    "tp://json-schema.org/draft-04/schema#\",\"properties\":{\"reference_file\":"
    "{\"type\":\"object\",\"properties\":{\"file_uuid\":{\"type\":\"string\",\"descripti"
    "on\":\"Control object file's Universally Unique Identifier (RFC "
    "4122)\"},\"file_path\":{\"type\":\"string\",\"description\":\"Path of the "
    "control object file relative to referring "
    "file\"}},\"required\":[\"file_uuid\",\"file_path\"],\"description\":\"Reference "
    "to a control object file\"}},\"description\":\"Details about the control "
    "object reference file\"}"
    ,
    /* example: */
    "{\"reference_file\":{\"file_uuid\":\"810f5d57-eccf-49ed-b07a-0cdd109b4213\","
    "\"file_path\":\"../../../10_CONTROL_OBJECTS/ControlPoints.cpx\"}}"
};

// Detection probability as a function of amplitude
const MetaDataItemInfo RDB_RIEGL_DETECTION_PROBABILITY = {
    /* name        */ "riegl.detection_probability",
    /* title       */ "Detection Probability",
    /* description */ "Detection probability as a function of amplitude",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Detection Probability\",\"$schema\":\"http://jso"
    "n-schema.org/draft-04/schema#\",\"description\":\"Detection probability as"
    " a function of amplitude\",\"properties\":{\"detection_probability\":{\"type"
    "\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"Detection "
    "probability [0..1]\"},\"amplitude\":{\"type\":\"array\",\"items\":{\"type\":\"numb"
    "er\"},\"description\":\"Amplitude "
    "[dB]\"}},\"required\":[\"amplitude\",\"detection_probability\"]}"
    ,
    /* example: */
    "{\"detection_probability\":[0.0,0.5,0.8,1.0,1.0,1.0,1.0,1.0,1.0,1.0,1.0]"
    ",\"amplitude\":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10.0]}"
};

// Details about the device used to acquire the point cloud
const MetaDataItemInfo RDB_RIEGL_DEVICE = {
    /* name        */ "riegl.device",
    /* title       */ "Device Information",
    /* description */ "Details about the device used to acquire the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Device Information\",\"$schema\":\"http://json-s"
    "chema.org/draft-04/schema#\",\"description\":\"Details about the device "
    "used to acquire the point cloud\",\"properties\":{\"channel_number\":{\"type"
    "\":\"integer\",\"exclusiveMinimum\":false,\"minimum\":0,\"description\":\"Laser "
    "channel number (not defined or 0: single channel "
    "device)\"},\"channel_text\":{\"type\":\"string\",\"description\":\"Optional "
    "channel description (e.g. 'Green Channel' for multi-channel "
    "devices)\"},\"serial_number\":{\"type\":\"string\",\"description\":\"Device "
    "serial number (e.g. "
    "S2221234)\"},\"device_type\":{\"type\":\"string\",\"description\":\"Device type "
    "identifier (e.g. "
    "VZ-400i)\"},\"device_build\":{\"type\":\"string\",\"description\":\"Device build"
    " variant\"},\"device_name\":{\"type\":\"string\",\"description\":\"Optional "
    "device name (e.g. 'Scanner 1' for multi-scanner "
    "systems)\"}},\"required\":[\"device_type\",\"serial_number\"]}"
    ,
    /* example: */
    "{\"channel_number\":0,\"channel_text\":\"\",\"serial_number\":\"S2221234\",\"devi"
    "ce_type\":\"VZ-400i\",\"device_build\":\"\",\"device_name\":\"Scanner 1\"}"
};

// Scanner device geometry details
const MetaDataItemInfo RDB_RIEGL_DEVICE_GEOMETRY = {
    /* name        */ "riegl.device_geometry",
    /* title       */ "Device Geometry",
    /* description */ "Scanner device geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Device Geometry\",\"$schema\":\"http://json-sche"
    "ma.org/draft-04/schema#\",\"description\":\"Scanner device geometry detail"
    "s\",\"properties\":{\"primary\":{\"type\":\"object\",\"properties\":{\"content\":{\""
    "type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"Internal "
    "calibration values\"},\"ID\":{\"type\":\"array\",\"items\":{\"type\":\"integer\"},\""
    "maxItems\":2,\"minItems\":2,\"description\":\"Structure "
    "identifier\"}},\"required\":[\"ID\",\"content\"],\"description\":\"Primary "
    "device geometry structure (mandatory)\"},\"secondary\":{\"type\":\"object\",\""
    "properties\":{\"content\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"desc"
    "ription\":\"Internal calibration values\"},\"ID\":{\"type\":\"array\",\"items\":{"
    "\"type\":\"integer\"},\"maxItems\":2,\"minItems\":2,\"description\":\"Structure "
    "identifier\"}},\"required\":[\"ID\",\"content\"],\"description\":\"Additional "
    "device geometry structure (optional)\"},\"amu\":{\"type\":\"object\",\"propert"
    "ies\":{\"frameCC\":{\"type\":\"number\",\"exclusiveMinimum\":false,\"minimum\":0,"
    "\"description\":\"Frame Circle Count (number of LSBs per full rotation "
    "about frame axis)\"},\"lineCC\":{\"type\":\"number\",\"exclusiveMinimum\":false"
    ",\"minimum\":0,\"description\":\"Line Circle Count (number of LSBs per full"
    " rotation about line axis)\"}},\"description\":\"Angle Measurement "
    "Unit\"}},\"required\":[\"primary\"]}"
    ,
    /* example: */
    "{\"primary\":{\"content\":[0],\"ID\":[4,0]},\"secondary\":{\"content\":[0],\"ID\":"
    "[91,0]},\"amu\":{\"frameCC\":124000,\"lineCC\":124000}}"
};

// Scanner passive channel device geometry details
const MetaDataItemInfo RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL = {
    /* name        */ "riegl.device_geometry_passive_channel",
    /* title       */ "Device Geometry Passive Channel",
    /* description */ "Scanner passive channel device geometry details",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Device Geometry Passive Channel\",\"$schema\":\""
    "http://json-schema.org/draft-04/schema#\",\"description\":\"Scanner "
    "passive channel device geometry details\",\"properties\":{\"primary\":{\"typ"
    "e\":\"object\",\"properties\":{\"content\":{\"type\":\"array\",\"items\":{\"type\":\"n"
    "umber\"},\"description\":\"Internal calibration values\"},\"ID\":{\"type\":\"arr"
    "ay\",\"items\":{\"type\":\"integer\"},\"maxItems\":2,\"minItems\":2,\"description\""
    ":\"Structure "
    "identifier\"}},\"required\":[\"ID\",\"content\"],\"description\":\"Primary "
    "device geometry structure (mandatory)\"}},\"required\":[\"primary\"]}"
    ,
    /* example: */
    "{\"primary\":{\"content\":[0],\"ID\":[143,0]}}"
};

// Limits of the measured values output by the device
const MetaDataItemInfo RDB_RIEGL_DEVICE_OUTPUT_LIMITS = {
    /* name        */ "riegl.device_output_limits",
    /* title       */ "Device Output Limits",
    /* description */ "Limits of the measured values output by the device",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Device Output Limits\",\"$schema\":\"http://json"
    "-schema.org/draft-04/schema#\",\"properties\":{\"range_minimum\":{\"type\":\"n"
    "umber\",\"description\":\"Minimum possible range in "
    "meters.\"},\"echo_count_maximum\":{\"type\":\"number\",\"description\":\"Maximum"
    " number of echoes a laser shot can "
    "have.\"},\"reflectance_minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "possible reflectance in dB.\"},\"background_radiation_maximum\":{\"type\":\""
    "number\",\"description\":\"Maximum possible background radiation.\"},\"ampli"
    "tude_minimum\":{\"type\":\"number\",\"description\":\"Minimum possible "
    "amplitude in "
    "dB.\"},\"amplitude_maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "possible amplitude in "
    "dB.\"},\"mta_zone_count_maximum\":{\"type\":\"number\",\"description\":\"Maximum"
    " number of MTA "
    "zones.\"},\"reflectance_maximum\":{\"type\":\"number\",\"description\":\"Maximum"
    " possible reflectance in "
    "dB.\"},\"range_maximum\":{\"type\":\"number\",\"description\":\"Maximum possible"
    " range in meters.\"},\"background_radiation_minimum\":{\"type\":\"number\",\"d"
    "escription\":\"Minimum possible background radiation.\"},\"deviation_maxim"
    "um\":{\"type\":\"number\",\"description\":\"Maximum possible pulse shape devia"
    "tion.\"},\"deviation_minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "possible pulse shape deviation.\"}},\"description\":\"Limits of the "
    "measured values output by the device. The limits depend on the device "
    "type, measurement program and/or scan pattern.\"}"
    ,
    /* example: */
    "{\"range_minimum\":2.9,\"range_maximum\":10000.0,\"mta_zone_count_maximum\":"
    "7,\"background_radiation_maximum\":0,\"background_radiation_minimum\":0,\"d"
    "eviation_maximum\":32767,\"amplitude_minimum\":0.0,\"amplitude_maximum\":10"
    "0.0,\"reflectance_maximum\":100.0,\"deviation_minimum\":-1,\"reflectance_mi"
    "nimum\":-100.0}"
};

// Details about the devices used to acquire the point cloud
const MetaDataItemInfo RDB_RIEGL_DEVICES = {
    /* name        */ "riegl.devices",
    /* title       */ "Devices Information",
    /* description */ "Details about the devices used to acquire the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"array\",\"items\":{\"type\":\"object\",\"properties\":{\"channel_number"
    "\":{\"type\":\"integer\",\"exclusiveMinimum\":false,\"minimum\":0,\"description\""
    ":\"Laser channel number (not defined or 0: single channel "
    "device)\"},\"channel_text\":{\"type\":\"string\",\"description\":\"Optional "
    "channel description (e.g. 'Green Channel' for multi-channel "
    "devices)\"},\"signed\":{\"type\":\"boolean\",\"description\":\"Flag that is set "
    "when the original 'riegl.device' entry in the source file was "
    "correctly "
    "signed.\"},\"serial_number\":{\"type\":\"string\",\"description\":\"Device "
    "serial number (e.g. "
    "S2221234)\"},\"device_type\":{\"type\":\"string\",\"description\":\"Device type "
    "identifier (e.g. "
    "VZ-400i)\"},\"device_build\":{\"type\":\"string\",\"description\":\"Device build"
    " variant\"},\"device_name\":{\"type\":\"string\",\"description\":\"Optional "
    "device name (e.g. 'Scanner 1' for multi-scanner systems)\"}},\"required\""
    ":[\"device_type\",\"serial_number\"]},\"title\":\"Devices Information\",\"$sche"
    "ma\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"Details "
    "about the devices used to acquire the point cloud (e.g. when merging "
    "point clouds of different devices)\"}"
    ,
    /* example: */
    "[{\"channel_number\":0,\"channel_text\":\"\",\"signed\":false,\"serial_number\":"
    "\"S2221234\",\"device_type\":\"VZ-400i\",\"device_build\":\"\",\"device_name\":\"Sc"
    "anner 1\"},{\"channel_number\":1,\"channel_text\":\"\",\"signed\":true,\"serial_"
    "number\":\"S2222680\",\"device_type\":\"VQ-1560i-DW\",\"device_build\":\"\",\"devi"
    "ce_name\":\"Scanner 2\"},{\"channel_number\":2,\"channel_text\":\"\",\"signed\":t"
    "rue,\"serial_number\":\"S2222680\",\"device_type\":\"VQ-1560i-DW\",\"device_bui"
    "ld\":\"\",\"device_name\":\"Scanner 3\"}]"
};

// Dyntrig
const MetaDataItemInfo RDB_RIEGL_DYNTRIG = {
    /* name        */ "riegl.dyntrig",
    /* title       */ "Dyntrig",
    /* description */ "Dyntrig",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"properties\":{\"post\":{\"type\":\"object\",\"properties\":{\"a\":{\"type\":\"arra"
    "y\",\"description\":\"...\",\"maxItems\":2080,\"minItems\":1,\"items\":{\"type\":\"n"
    "umber\"}},\"nc\":{\"type\":\"integer\",\"description\":\"Number of entries\",\"min"
    "imum\":0,\"maximum\":255}},\"required\":[\"nc\",\"a\"],\"description\":\"Dyntrig "
    "post values\"},\"scale\":{\"type\":\"number\",\"description\":\"Scale in units "
    "of dB, for calculation of line: line number N=(amplitude-offset)/scale"
    "\"},\"tab\":{\"type\":\"array\",\"description\":\"...\",\"maxItems\":128,\"minItems\""
    ":1,\"items\":{\"type\":\"object\",\"properties\":{\"del1\":{\"type\":\"number\",\"des"
    "cription\":\"Length of constant post-trigger threshold elevation in "
    "units of m\"},\"thra2\":{\"type\":\"number\",\"description\":\"Pre-trigger "
    "threshold in units of dB\"},\"dec2\":{\"type\":\"number\",\"description\":\"Rise"
    " of pre-trigger threshold after del2 in units of "
    "dB/m\"},\"dec1\":{\"type\":\"number\",\"description\":\"Decay of post-trigger "
    "threshold after del1 in units of "
    "dB/m\"},\"thra1\":{\"type\":\"number\",\"description\":\"Post-trigger threshold "
    "in units of dB\"},\"del2\":{\"type\":\"number\",\"description\":\"Length of "
    "constant pre-trigger threshold elevation in units of m\"}},\"required\":["
    "\"thra1\",\"del1\",\"dec1\",\"thra2\",\"del2\",\"dec2\"],\"description\":\"...\"}},\"pr"
    "e\":{\"type\":\"object\",\"properties\":{\"a\":{\"type\":\"array\",\"description\":\"."
    "..\",\"maxItems\":2080,\"minItems\":1,\"items\":{\"type\":\"number\"}},\"nc\":{\"typ"
    "e\":\"integer\",\"description\":\"Number of entries\",\"minimum\":0,\"maximum\":2"
    "55}},\"required\":[\"nc\",\"a\"],\"description\":\"Dyntrig pre "
    "values\"},\"offset\":{\"type\":\"number\",\"description\":\"Offset in units of "
    "dB, for calculation of line\"}},\"title\":\"Dyntrig\",\"$schema\":\"http://jso"
    "n-schema.org/draft-04/schema#\",\"description\":\"Dyntrig\"}"
    ,
    /* example: */
    "{\"post\":{\"a\":[78,86,126,134,31],\"nc\":128},\"scale\":1.0,\"tab\":[{\"del1\":0"
    ".0,\"thra2\":0.0,\"dec2\":0.0,\"dec1\":0.0,\"thra1\":0.0,\"del2\":0.0}],\"pre\":{\""
    "a\":[78,86,126,134,31],\"nc\":128},\"offset\":0.0}"
};

// Details about echo files
const MetaDataItemInfo RDB_RIEGL_ECHO_INFO = {
    /* name        */ "riegl.echo_info",
    /* title       */ "Echo Information",
    /* description */ "Details about echo files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Echo Information\",\"$schema\":\"http://json-sch"
    "ema.org/draft-04/schema#\",\"description\":\"Details about echo files\",\"pr"
    "operties\":{\"echo_file\":{\"type\":\"object\",\"properties\":{\"file_uuid\":{\"ty"
    "pe\":\"string\",\"description\":\"File's Universally Unique Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Echo file "
    "extension, without the leading "
    "dot\"}},\"required\":[\"file_extension\"]}},\"required\":[\"echo_file\"]}"
    ,
    /* example: */
    "{\"echo_file\":{\"file_uuid\":\"26a03615-67c0-4bea-8fe8-c577378fe661\",\"file"
    "_extension\":\"owp\"}}"
};

// Details for exponential decomposition of full waveform data
const MetaDataItemInfo RDB_RIEGL_EXPONENTIAL_DECOMPOSITION = {
    /* name        */ "riegl.exponential_decomposition",
    /* title       */ "Exponential Decomposition",
    /* description */ "Details for exponential decomposition of full waveform data",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"patternProperties\":{\"^[0-9]+$\":{\"$ref\":\"#/definition"
    "s/channel\",\"description\":\"one field per channel, field name is channel"
    " index\"}},\"definitions\":{\"channel\":{\"type\":\"object\",\"properties\":{\"sca"
    "le\":{\"type\":\"number\",\"description\":\"amplitude calibration\"},\"a_lin\":{\""
    "type\":\"number\",\"minimum\":0,\"exclusiveMinimum\":false,\"maximum\":1,\"descr"
    "iption\":\"relative linear amplitude range [0..1]\",\"exclusiveMaximum\":fa"
    "lse},\"parameter\":{\"type\":\"object\",\"properties\":{\"gamma\":{\"type\":\"array"
    "\",\"items\":{\"type\":\"number\"},\"description\":\"decay in 1/second\"},\"omega\""
    ":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"angular "
    "frequency in "
    "Hz\"},\"A\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"real"
    " part of amplitude factor in units of full-scale\"},\"B\":{\"type\":\"array\""
    ",\"items\":{\"type\":\"number\"},\"description\":\"imaginary part of amplitude "
    "factor in units of full-scale\"}},\"required\":[\"A\",\"B\",\"gamma\",\"omega\"],"
    "\"description\":\"parameters of the syswave exponential "
    "sum\"},\"delay\":{\"type\":\"number\",\"description\":\"delay calibration in sec"
    "onds\"}},\"required\":[\"delay\",\"scale\",\"parameter\"]}},\"$schema\":\"http://j"
    "son-schema.org/draft-04/schema#\",\"additionalProperties\":false,\"descrip"
    "tion\":\"Details for exponential decomposition of full waveform "
    "data\",\"title\":\"Exponential Decomposition\"}"
    ,
    /* example: */
    "{\"0\":{\"scale\":1.0,\"a_lin\":0.27,\"parameter\":{\"gamma\":[-1094726528.0,-76"
    "9562752.0,-848000064.0],\"omega\":[352020896.0,3647927552.0,-1977987072."
    "0],\"A\":[0.9772450923919678,0.3354335129261017,-1.312678575515747],\"B\":"
    "[-3.9813032150268555,0.08622030913829803,-0.3152860999107361]},\"delay\""
    ":3.783458418887631e-09},\"1\":{\"scale\":1.0,\"a_lin\":0.9,\"parameter\":{\"gam"
    "ma\":[-1094726528.0,-769562752.0,-848000064.0],\"omega\":[352020896.0,364"
    "7927552.0,-1977987072.0],\"A\":[0.9,0.3,-1.3],\"B\":[-3.9,0.0,-0.3]},\"dela"
    "y\":3.5e-09}}"
};

// Details for Gaussian decomposition of full waveform data
const MetaDataItemInfo RDB_RIEGL_GAUSSIAN_DECOMPOSITION = {
    /* name        */ "riegl.gaussian_decomposition",
    /* title       */ "Gaussian Decomposition",
    /* description */ "Details for Gaussian decomposition of full waveform data",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Gaussian Decomposition\",\"$schema\":\"http://js"
    "on-schema.org/draft-04/schema#\",\"description\":\"riegl.gaussian_decompos"
    "ition contains information relevant for extracting calibrated "
    "amplitudes and calibrated ranges from a Gaussian decomposition of full"
    " waveform data. This information is contained in a table with five "
    "columns. Two columns are to be used as input: amplitude_lsb_low_power "
    "and amplitude_lsb_high_power. The other three columns provide the "
    "outputs. Amplitude_db gives the calibrated amplitude in the optical "
    "regime in decibels. The range offset columns provide additive range "
    "offsets, given in units of seconds, for each channel.\",\"properties\":{\""
    "amplitude_db\":{\"type\":\"array\",\"items\":{\"type\":\"number\"}},\"amplitude_ls"
    "b_low_power\":{\"type\":\"array\",\"items\":{\"type\":\"number\"}},\"range_offset_"
    "sec_low_power\":{\"type\":\"array\",\"items\":{\"type\":\"number\"}},\"range_offse"
    "t_sec_high_power\":{\"type\":\"array\",\"items\":{\"type\":\"number\"}},\"amplitud"
    "e_lsb_high_power\":{\"type\":\"array\",\"items\":{\"type\":\"number\"}}},\"require"
    "d\":[\"amplitude_lsb_low_power\",\"amplitude_lsb_high_power\",\"amplitude_db"
    "\",\"range_offset_sec_low_power\",\"range_offset_sec_high_power\"]}"
    ,
    /* example: */
    "{\"amplitude_db\":[],\"amplitude_lsb_low_power\":[],\"range_offset_sec_low_"
    "power\":[],\"range_offset_sec_high_power\":[],\"amplitude_lsb_high_power\":"
    "[]}"
};

// Point cloud georeferencing information
const MetaDataItemInfo RDB_RIEGL_GEO_TAG = {
    /* name        */ "riegl.geo_tag",
    /* title       */ "Geo Tag",
    /* description */ "Point cloud georeferencing information",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Geo Tag\",\"$schema\":\"http://json-schema.org/d"
    "raft-04/schema#\",\"properties\":{\"crs\":{\"type\":\"object\",\"properties\":{\"e"
    "psg\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"EPSG "
    "code\"},\"name\":{\"type\":\"string\",\"description\":\"Coordinate reference "
    "system name\"},\"wkt\":{\"type\":\"string\",\"description\":\"\\\"Well-Known "
    "Text\\\" string, OGC WKT dialect (see http://www.opengeospatial.org/stan"
    "dards/wkt-crs)\"}},\"description\":\"Global Coordinate Reference System. "
    "Please note that only 3D Cartesian Coordinate Systems are allowed.\"},\""
    "pose\":{\"type\":\"array\",\"items\":{\"type\":\"array\",\"items\":{\"type\":\"number\""
    ",\"description\":\"columns\"},\"minItems\":4,\"maxItems\":4,\"description\":\"row"
    "s\"},\"minItems\":4,\"maxItems\":4,\"description\":\"Coordinate Transformation"
    " Matrix to transform from File Coordinate System to Global Coordinate "
    "Reference System. 4x4 matrix stored as two dimensional array, row "
    "major order.\"}},\"description\":\"Point cloud georeferencing "
    "information\"}"
    ,
    /* example: */
    "{\"crs\":{\"epsg\":4978,\"name\":\"WGS84 Geocentric\",\"wkt\":\"GEOCCS[\\\"WGS84 Ge"
    "ocentric\\\",DATUM[\\\"WGS84\\\",SPHEROID[\\\"WGS84\\\",6378137.000,298.25722356"
    "3,AUTHORITY[\\\"EPSG\\\",\\\"7030\\\"]],AUTHORITY[\\\"EPSG\\\",\\\"6326\\\"]],PRIMEM[\\"
    "\"Greenwich\\\",0.0000000000000000,AUTHORITY[\\\"EPSG\\\",\\\"8901\\\"]],UNIT[\\\"M"
    "eter\\\",1.00000000000000000000,AUTHORITY[\\\"EPSG\\\",\\\"9001\\\"]],AXIS[\\\"X\\\""
    ",OTHER],AXIS[\\\"Y\\\",EAST],AXIS[\\\"Z\\\",NORTH],AUTHORITY[\\\"EPSG\\\",\\\"4978\\\""
    "]]\"},\"pose\":[[-0.269827776749716,-0.723017716139738,0.635954678449952,"
    "4063882.500831],[0.962908599449764,-0.20260517250352,0.178208229833847"
    ",1138787.607461],[0.0,0.660451759194338,0.7508684796801,4766084.550196"
    "],[0.0,0.0,0.0,1.0]]}"
};

// Geometric scale factor applied to point coordinates
const MetaDataItemInfo RDB_RIEGL_GEOMETRIC_SCALE_FACTOR = {
    /* name        */ "riegl.geometric_scale_factor",
    /* title       */ "Geometric Scale Factor",
    /* description */ "Geometric scale factor applied to point coordinates",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"number\",\"exclusiveMinimum\":true,\"minimum\":0,\"$schema\":\"http:/"
    "/json-schema.org/draft-04/schema#\",\"description\":\"Geometric scale "
    "factor applied to point coordinates\"}"
    ,
    /* example: */
    "1.0"
};

// Parameters used for georeferencing of the point cloud
const MetaDataItemInfo RDB_RIEGL_GEOREFERENCING_PARAMETERS = {
    /* name        */ "riegl.georeferencing_parameters",
    /* title       */ "Georeferencing Parameters",
    /* description */ "Parameters used for georeferencing of the point cloud",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Georeferencing Parameters\",\"$schema\":\"http:/"
    "/json-schema.org/draft-04/schema#\",\"properties\":{\"trajectory_file\":{\"t"
    "ype\":\"object\",\"properties\":{\"file_uuid\":{\"type\":\"string\",\"description\""
    ":\"File's Universally Unique Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Trajectory "
    "file extension, without the leading "
    "dot\"}},\"required\":[\"file_extension\"],\"description\":\"Trajectory data "
    "used for georeferencing of the point cloud\"},\"socs_to_body_matrix\":{\"t"
    "ype\":\"array\",\"items\":{\"type\":\"array\",\"items\":{\"type\":\"number\",\"descrip"
    "tion\":\"columns\"},\"minItems\":4,\"maxItems\":4,\"description\":\"rows\"},\"minI"
    "tems\":4,\"maxItems\":4,\"description\":\"Coordinate Transformation Matrix "
    "to transform from Scanner's Own Coordinate System to Body Coordinate "
    "System. 4x4 matrix stored as two dimensional array, row major order.\"}"
    ",\"body_coordinate_system_type\":{\"type\":\"string\",\"enum\":[\"NED\",\"ENU\"],\""
    "description\":\"BODY coordinate frame (NED: North-East-Down, ENU: "
    "East-North-Up), default: NED\"},\"trajectory_offsets\":{\"type\":\"object\",\""
    "properties\":{\"version\":{\"type\":\"integer\",\"description\":\"Meaning of "
    "offset values and how to apply them; version 0: "
    "Rz(yaw+offset_yaw)*Ry(pitch+offset_pitch)*Rx(roll+offset_roll), "
    "version 1: Rz(yaw)*Ry(pitch)*Rx(roll) * Rz(offset_yaw)*Ry(offset_pitch"
    ")*Rx(offset_roll)\"},\"offset_yaw\":{\"type\":\"number\",\"description\":\"[deg]"
    "\"},\"offset_pitch\":{\"type\":\"number\",\"description\":\"[deg]\"},\"offset_heig"
    "ht\":{\"type\":\"number\",\"description\":\"[m]\"},\"offset_roll\":{\"type\":\"numbe"
    "r\",\"description\":\"[deg]\"},\"offset_north\":{\"type\":\"number\",\"description"
    "\":\"[m]\"},\"offset_time\":{\"type\":\"number\",\"description\":\"[s]\"},\"offset_e"
    "ast\":{\"type\":\"number\",\"description\":\"[m]\"}},\"description\":\"Correction "
    "offsets applied to the trajectory data\"},\"socs_to_rocs_matrix\":{\"type\""
    ":\"array\",\"items\":{\"type\":\"array\",\"items\":{\"type\":\"number\",\"description"
    "\":\"columns\"},\"minItems\":4,\"maxItems\":4,\"description\":\"rows\"},\"minItems"
    "\":4,\"maxItems\":4,\"description\":\"Coordinate Transformation Matrix to "
    "transform from Scanner's Own Coordinate System to Record Coordinate "
    "System. 4x4 matrix stored as two dimensional array, row major "
    "order.\"}},\"description\":\"Parameters used for georeferencing of the "
    "point cloud\"}"
    ,
    /* example: */
    "{\"trajectory_file\":{\"file_uuid\":\"93a03615-66c0-4bea-8ff8-c577378fe660\""
    ",\"file_extension\":\"pofx\"},\"socs_to_body_matrix\":[[-0.269827776749716,-"
    "0.723017716139738,0.635954678449952,0.0],[0.962908599449764,-0.2026051"
    "7250352,0.178208229833847,0.0],[0.0,0.660451759194338,0.7508684796801,"
    "0.0],[0.0,0.0,0.0,1.0]],\"body_coordinate_system_type\":\"NED\",\"trajector"
    "y_offsets\":{\"version\":0,\"offset_yaw\":-0.45,\"offset_pitch\":0.01,\"offset"
    "_height\":-0.2,\"offset_roll\":0.03,\"offset_north\":0.07,\"offset_time\":18."
    "007,\"offset_east\":0.15}}"
};

// Map of item names
const MetaDataItemInfo RDB_RIEGL_ITEM_NAMES = {
    /* name        */ "riegl.item_names",
    /* title       */ "Item Names",
    /* description */ "Map of item names",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"patternProperties\":{\"^-?[0-9]+$\":{\"type\":\"string\",\"d"
    "escription\":\"One field per item, field name is item id, field value is"
    " item name\"}},\"title\":\"Item Names\",\"$schema\":\"http://json-schema.org/d"
    "raft-04/schema#\",\"description\":\"Map of item "
    "names\",\"additionalProperties\":false}"
    ,
    /* example: */
    "{\"2\":\"Name of item with id 2\",\"-1\":\"Name of item with id "
    "-1\",\"47\":\"Name of item with id 47\",\"1\":\"Name of item with id 1\"}"
};

// License keys for software features
const MetaDataItemInfo RDB_RIEGL_LICENSES = {
    /* name        */ "riegl.licenses",
    /* title       */ "Software License Keys",
    /* description */ "License keys for software features",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"patternProperties\":{\"^.*$\":{\"type\":\"array\",\"items\":{"
    "\"type\":\"string\",\"description\":\"License key (example: '46AE032A - "
    "39882AC4 - 9EC0A184 - 6F163D73')\"},\"minItems\":1,\"description\":\"Each "
    "field of the object represents a feature and holds a list of license "
    "keys, where the field name is the feature name.\"}},\"title\":\"Software "
    "License Keys\",\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"des"
    "cription\":\"License keys for software "
    "features\",\"additionalProperties\":false}"
    ,
    /* example: */
    "{\"Full Waveform Analysis Topography with GPU support\":[\"8AB44126 - "
    "23B92250 - 16E2689F - 34EF7E7B\"],\"Georeferencing\":[\"46AE032A - "
    "39882AC4 - 9EC0A184 - 6F163D73\"],\"MTA resolution\":[\"468E020A - "
    "39A922E4 - B681A184 - 673E3D72\"],\"Full Waveform Analysis "
    "Topography\":[\"0FD5FF07 - 011A1255 - 9F76CACA - 8D2ED557\"]}"
};

// Parameters for MTA processing
const MetaDataItemInfo RDB_RIEGL_MTA_SETTINGS = {
    /* name        */ "riegl.mta_settings",
    /* title       */ "MTA Settings",
    /* description */ "Parameters for MTA processing",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"MTA Settings\",\"$schema\":\"http://json-schema."
    "org/draft-04/schema#\",\"properties\":{\"zone_width\":{\"type\":\"number\",\"min"
    "imum\":0,\"description\":\"Width of a MTA zone in meter.\"},\"modulation_dep"
    "th\":{\"type\":\"number\",\"minimum\":0,\"description\":\"Depth of pulse "
    "position modulation in meter.\"},\"zone_count\":{\"type\":\"integer\",\"maximu"
    "m\":255,\"minimum\":0,\"description\":\"Maximum number of MTA "
    "zones.\"}},\"description\":\"Parameters for MTA processing\"}"
    ,
    /* example: */
    "{\"zone_width\":149.896225,\"modulation_depth\":9.368514,\"zone_count\":23}"
};

// Lookup table for range correction based on raw range
const MetaDataItemInfo RDB_RIEGL_NEAR_RANGE_CORRECTION = {
    /* name        */ "riegl.near_range_correction",
    /* title       */ "Near Range Correction Table",
    /* description */ "Lookup table for range correction based on raw range",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Near Range Correction Table\",\"$schema\":\"http"
    "://json-schema.org/draft-04/schema#\",\"description\":\"Lookup table for "
    "range correction based on raw "
    "range\",\"properties\":{\"delta\":{\"type\":\"number\",\"description\":\"Delta "
    "between table entries [m], first entry is at range = 0 m\"},\"content\":{"
    "\"type\":\"array\",\"items\":{\"type\":\"number\"},\"maxItems\":2000,\"minItems\":1,"
    "\"description\":\"Correction value [m] to be added to the raw "
    "range\"}},\"required\":[\"delta\",\"content\"]}"
    ,
    /* example: */
    "{\"delta\":0.512,\"content\":[0.0]}"
};

// Standard deviation for range and amplitude as a function of amplitude
const MetaDataItemInfo RDB_RIEGL_NOISE_ESTIMATES = {
    /* name        */ "riegl.noise_estimates",
    /* title       */ "Noise Estimates",
    /* description */ "Standard deviation for range and amplitude as a function of amplitude",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Noise Estimates\",\"$schema\":\"http://json-sche"
    "ma.org/draft-04/schema#\",\"description\":\"Standard deviation for range "
    "and amplitude as a function of amplitude\",\"properties\":{\"amplitude_sig"
    "ma\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"Sigma "
    "amplitude [dB]\"},\"amplitude\":{\"type\":\"array\",\"items\":{\"type\":\"number\"}"
    ",\"description\":\"Amplitude [dB]\"},\"range_sigma\":{\"type\":\"array\",\"items\""
    ":{\"type\":\"number\"},\"description\":\"Sigma range "
    "[m]\"}},\"required\":[\"amplitude\",\"range_sigma\",\"amplitude_sigma\"]}"
    ,
    /* example: */
    "{\"amplitude_sigma\":[0.988,0.988,0.875,0.774,0.686,0.608,0.54,0.482,0.4"
    "32,0.39,0.354],\"amplitude\":[0.0,1.0,2.0,3.0,4.0,5.0,6.0,7.0,8.0,9.0,10"
    ".0],\"range_sigma\":[0.065,0.056,0.046,0.038,0.032,0.027,0.024,0.021,0.0"
    "18,0.016,0.014]}"
};

// Notch filter parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_NOTCH_FILTER = {
    /* name        */ "riegl.notch_filter",
    /* title       */ "Notch Filter",
    /* description */ "Notch filter parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Notch Filter\",\"$schema\":\"http://json-schema."
    "org/draft-04/schema#\",\"description\":\"Notch filter parameters for "
    "window glass echoes\",\"properties\":{\"range_minimum\":{\"type\":\"number\",\"d"
    "escription\":\"Minimum range "
    "[m]\"},\"range_maximum\":{\"type\":\"number\",\"description\":\"Maximum range [m"
    "]\"},\"amplitude_maximum\":{\"type\":\"number\",\"minimum\":0,\"description\":\"Ma"
    "ximum amplitude [dB]\"}},\"required\":[\"range_minimum\",\"range_maximum\",\"a"
    "mplitude_maximum\"]}"
    ,
    /* example: */
    "{\"range_minimum\":-0.5,\"range_maximum\":0.2,\"amplitude_maximum\":18.0}"
};

// Details about the pixels contained in the file
const MetaDataItemInfo RDB_RIEGL_PIXEL_INFO = {
    /* name        */ "riegl.pixel_info",
    /* title       */ "Pixel Information",
    /* description */ "Details about the pixels contained in the file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"definitions\":{\"pixel_size\":{\"type\":\"array\",\"items\":{"
    "\"type\":\"number\",\"minimum\":0,\"description\":\"Length of pixel edge "
    "[m].\"},\"minItems\":2,\"maxItems\":2,\"description\":\"Size of pixels.\"}},\"$s"
    "chema\":\"http://json-schema.org/draft-04/schema#\",\"description\":\"Detail"
    "s about the pixels contained in the file\",\"title\":\"Pixel Information\","
    "\"properties\":{\"size_llcs\":{\"$ref\":\"#/definitions/pixel_size\",\"descript"
    "ion\":\"Size of pixels in a locally levelled cartesian coordinate system"
    " (xy). This is only used for pixels based on a map projection.\"},\"size"
    "\":{\"$ref\":\"#/definitions/pixel_size\",\"description\":\"Size of pixels in "
    "file coordinate system.\"}},\"required\":[\"size\"]}"
    ,
    /* example: */
    "{\"size_llcs\":[0.5156575252891171,0.5130835356683303],\"size\":[0.5971642"
    "834779395,0.5971642834779395]}"
};

// Details about the plane patch matching process
const MetaDataItemInfo RDB_RIEGL_PLANE_PATCH_MATCHING = {
    /* name        */ "riegl.plane_patch_matching",
    /* title       */ "Plane Patch Matching",
    /* description */ "Details about the plane patch matching process",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"definitions\":{\"file_reference\":{\"type\":\"object\",\"pro"
    "perties\":{\"file_uuid\":{\"type\":\"string\",\"description\":\"Plane patch "
    "file's Universally Unique Identifier (RFC "
    "4122)\"},\"file_path\":{\"type\":\"string\",\"description\":\"Path of the plane "
    "patch file relative to the match "
    "file\"}},\"required\":[\"file_uuid\",\"file_path\"],\"description\":\"Reference "
    "to a plane patch file\"}},\"$schema\":\"http://json-schema.org/draft-04/sc"
    "hema#\",\"description\":\"Details about the plane patch matching "
    "process\",\"title\":\"Plane Patch Matching\",\"properties\":{\"plane_patch_fil"
    "e_one\":{\"$ref\":\"#/definitions/file_reference\",\"description\":\"Reference"
    " to the plane patch file one\"},\"plane_patch_file_two\":{\"$ref\":\"#/defin"
    "itions/file_reference\",\"description\":\"Reference to the plane patch "
    "file "
    "two\"}},\"required\":[\"plane_patch_file_one\",\"plane_patch_file_two\"]}"
    ,
    /* example: */
    "{\"plane_patch_file_one\":{\"file_uuid\":\"810f5d57-eccf-49ed-b07a-0cdd109b"
    "4213\",\"file_path\":\"Record009_Line001/191025_121410_Scanner_1.ptch\"},\"p"
    "lane_patch_file_two\":{\"file_uuid\":\"fa47d509-a64e-49ce-8b14-ff3130fbefa"
    "9\",\"file_path\":\"project.ptch\"}}"
};

// Statistics about plane patches found by plane patch extractor
const MetaDataItemInfo RDB_RIEGL_PLANE_PATCH_STATISTICS = {
    /* name        */ "riegl.plane_patch_statistics",
    /* title       */ "Plane Patch Statistics",
    /* description */ "Statistics about plane patches found by plane patch extractor",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Plane Patch Statistics\",\"$schema\":\"http://js"
    "on-schema.org/draft-04/schema#\",\"properties\":{\"total_area\":{\"type\":\"nu"
    "mber\",\"description\":\"sum of all plane patch areas [m\\u00b2]\"},\"total_h"
    "orizontal_area\":{\"type\":\"number\",\"description\":\"sum of all plane patch"
    " areas projected to horizontal plane "
    "[m\\u00b2]\"}},\"description\":\"Statistics about plane patches found by "
    "plane patch extractor\"}"
    ,
    /* example: */
    "{\"total_area\":14007.965,\"total_horizontal_area\":13954.601}"
};

// Settings and classes for plane slope classification
const MetaDataItemInfo RDB_RIEGL_PLANE_SLOPE_CLASS_INFO = {
    /* name        */ "riegl.plane_slope_class_info",
    /* title       */ "Plane Slope Class Info",
    /* description */ "Settings and classes for plane slope classification",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"definitions\":{\"method-1\":{\"type\":\"object\",\"propertie"
    "s\":{\"plane_classification_method\":{\"type\":\"integer\",\"maximum\":1,\"minim"
    "um\":1,\"description\":\"method ID (=1)\"},\"maximum_inclination_angle_horiz"
    "ontal\":{\"type\":\"number\",\"maximum\":360.0,\"minimum\":-360.0,\"description\""
    ":\"maximum inclination angle of horizontal plane patches [deg]\"}},\"requ"
    "ired\":[\"plane_classification_method\",\"maximum_inclination_angle_horizo"
    "ntal\"],\"description\":\"Classification method 1\"},\"method-2\":{\"type\":\"ob"
    "ject\",\"properties\":{\"plane_classification_method\":{\"type\":\"integer\",\"m"
    "aximum\":2,\"minimum\":2,\"description\":\"method ID (=2)\"},\"sloping_plane_c"
    "lasses_minimum_angle\":{\"type\":\"number\",\"maximum\":360.0,\"minimum\":-360."
    "0,\"description\":\"minimum inclination angle of sloping plane patches [d"
    "eg]\"},\"sloping_plane_classes_maximum_angle\":{\"type\":\"number\",\"maximum\""
    ":360.0,\"minimum\":-360.0,\"description\":\"maximum inclination angle of "
    "sloping plane patches [deg]\"}},\"required\":[\"plane_classification_metho"
    "d\",\"sloping_plane_classes_minimum_angle\",\"sloping_plane_classes_maximu"
    "m_angle\"],\"description\":\"Classification method 2\"}},\"$schema\":\"http://"
    "json-schema.org/draft-04/schema#\",\"description\":\"Settings and classes "
    "for plane slope classification\",\"title\":\"Plane Slope Class Info\",\"prop"
    "erties\":{\"classes\":{\"type\":\"object\",\"patternProperties\":{\"^[0-9]+$\":{\""
    "type\":\"string\",\"description\":\"one field per class, field name is class"
    " number, field value is class "
    "name\"}},\"additionalProperties\":false,\"description\":\"Class definition t"
    "able\"},\"settings\":{\"type\":\"object\",\"oneOf\":[{\"$ref\":\"#/definitions/met"
    "hod-1\"},{\"$ref\":\"#/definitions/method-2\"}],\"description\":\"Classificati"
    "on settings, details see documentation of "
    "rdbplanes\"}},\"required\":[\"settings\",\"classes\"]}"
    ,
    /* example: */
    "{\"classes\":{\"12\":\"sloping, pointing down and north\",\"6\":\"vertical, "
    "pointing east\",\"4\":\"sloping, pointing up and north\",\"13\":\"sloping, "
    "pointing down and west\",\"8\":\"vertical, pointing north\",\"7\":\"vertical, "
    "pointing south\",\"2\":\"sloping, pointing up and east\",\"10\":\"sloping, "
    "pointing down and east\",\"3\":\"sloping, pointing up and "
    "south\",\"14\":\"horizontal, pointing down\",\"9\":\"vertical, pointing "
    "west\",\"5\":\"sloping, pointing up and west\",\"11\":\"sloping, pointing down"
    " and south\",\"1\":\"horizontal, pointing up\"},\"settings\":{\"plane_classifi"
    "cation_method\":2,\"sloping_plane_classes_minimum_angle\":10.0,\"sloping_p"
    "lane_classes_maximum_angle\":70.0}}"
};

// Grouping and sorting of point attributes for visualization purposes
const MetaDataItemInfo RDB_RIEGL_POINT_ATTRIBUTE_GROUPS = {
    /* name        */ "riegl.point_attribute_groups",
    /* title       */ "Point Attribute Groups",
    /* description */ "Grouping and sorting of point attributes for visualization purposes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"patternProperties\":{\"^.*$\":{\"type\":\"array\",\"items\":{"
    "\"type\":\"string\",\"description\":\"Point attribute full name or name "
    "pattern (perl regular expression "
    "syntax)\"},\"minItems\":1,\"description\":\"Each field of the object "
    "represents a point attribute group and holds a list of point "
    "attributes, where the field name is the group name.\"}},\"title\":\"Point "
    "Attribute Groups\",\"$schema\":\"http://json-schema.org/draft-04/schema#\","
    "\"description\":\"Grouping and sorting of point attributes for "
    "visualization purposes\",\"additionalProperties\":false}"
    ,
    /* example: */
    "{\"Secondary "
    "Attributes\":[\"riegl.mirror_facet\",\"riegl.waveform_available\"],\"Other A"
    "ttributes\":[\"riegl.selected\",\"riegl.visible\"],\"Coordinates/Vectors\":[\""
    "riegl.xyz\",\"riegl.range\",\"riegl.theta\",\"riegl.phi\"],\"Primary Attribute"
    "s\":[\"riegl.reflectance\",\"riegl.amplitude\",\"riegl.deviation\"],\"Time\":[\""
    "riegl.timestamp\"]}"
};

// Details about point cloud files
const MetaDataItemInfo RDB_RIEGL_POINTCLOUD_INFO = {
    /* name        */ "riegl.pointcloud_info",
    /* title       */ "Point Cloud Information",
    /* description */ "Details about point cloud files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Point Cloud Information\",\"$schema\":\"http://j"
    "son-schema.org/draft-04/schema#\",\"properties\":{\"field_of_application\":"
    "{\"type\":\"string\",\"enum\":[\"unknown\",\"SLS\",\"TLS\",\"KLS\",\"MLS\",\"ULS\",\"ALS\""
    ",\"BLS\",\"ILS\"],\"description\":\"Field of application\"},\"comments\":{\"type\""
    ":\"string\",\"description\":\"Comments\"},\"project\":{\"type\":\"string\",\"descri"
    "ption\":\"Project name\"}},\"description\":\"Details about point cloud "
    "files\"}"
    ,
    /* example: */
    "{\"field_of_application\":\"ALS\",\"comments\":\"Line 3\",\"project\":\"Campaign "
    "4\"}"
};

// Estimated position and orientation information
const MetaDataItemInfo RDB_RIEGL_POSE_ESTIMATION = {
    /* name        */ "riegl.pose_estimation",
    /* title       */ "Pose Estimation",
    /* description */ "Estimated position and orientation information",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Pose Estimation\",\"$schema\":\"http://json-sche"
    "ma.org/draft-04/schema#\",\"description\":\"Estimated position and "
    "orientation information as measured by GNSS, IMU or inclination sensor"
    "s\",\"properties\":{\"position\":{\"type\":\"object\",\"properties\":{\"horizontal"
    "_accuracy\":{\"type\":\"number\",\"exclusiveMinimum\":true,\"minimum\":0,\"descr"
    "iption\":\"Horizontal accuracy [m]\"},\"crs\":{\"type\":\"object\",\"properties\""
    ":{\"epsg\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"EPSG "
    "code\"},\"wkt\":{\"type\":\"string\",\"description\":\"\\\"Well-Known Text\\\" "
    "string, OGC WKT dialect (see http://www.opengeospatial.org/standards/w"
    "kt-crs)\"}},\"required\":[\"epsg\"],\"description\":\"Global Coordinate "
    "Reference "
    "System\"},\"coordinate_3\":{\"type\":\"number\",\"description\":\"Coordinate 3 "
    "as defined by axis 3 of the specified CRS (e.g., Z, Altitude)\"},\"verti"
    "cal_accuracy\":{\"type\":\"number\",\"exclusiveMinimum\":true,\"minimum\":0,\"de"
    "scription\":\"Vertical accuracy "
    "[m]\"},\"coordinate_2\":{\"type\":\"number\",\"description\":\"Coordinate 2 as "
    "defined by axis 2 of the specified CRS (e.g., Y, "
    "Longitude)\"},\"coordinate_1\":{\"type\":\"number\",\"description\":\"Coordinate"
    " 1 as defined by axis 1 of the specified CRS (e.g., X, Latitude)\"}},\"r"
    "equired\":[\"coordinate_1\",\"coordinate_2\",\"coordinate_3\",\"horizontal_acc"
    "uracy\",\"vertical_accuracy\",\"crs\"],\"description\":\"Position coordinates "
    "and position accuracy values as measured by GNSS in the specified "
    "Coordinate Reference System (CRS)\"},\"orientation\":{\"type\":\"object\",\"pr"
    "operties\":{\"yaw_accuracy\":{\"type\":\"number\",\"exclusiveMinimum\":true,\"mi"
    "nimum\":0,\"description\":\"Yaw angle accuracy [deg]\"},\"roll_accuracy\":{\"t"
    "ype\":\"number\",\"exclusiveMinimum\":true,\"minimum\":0,\"description\":\"Roll "
    "angle accuracy [deg]\"},\"pitch_accuracy\":{\"type\":\"number\",\"exclusiveMin"
    "imum\":true,\"minimum\":0,\"description\":\"Pitch angle accuracy [deg]\"},\"ro"
    "ll\":{\"type\":\"number\",\"maximum\":360,\"minimum\":-360,\"description\":\"Roll "
    "angle about scanner X-axis [deg]\"},\"pitch\":{\"type\":\"number\",\"maximum\":"
    "360,\"minimum\":-360,\"description\":\"Pitch angle about scanner Y-axis [de"
    "g]\"},\"yaw\":{\"type\":\"number\",\"maximum\":360,\"minimum\":-360,\"description\""
    ":\"Yaw angle about scanner Z-axis [deg]\"}},\"required\":[\"roll\",\"pitch\",\""
    "yaw\",\"roll_accuracy\",\"pitch_accuracy\",\"yaw_accuracy\"],\"description\":\"O"
    "rientation values and orientation accuracies, measured with IMU or "
    "inclination sensors.\"},\"barometric_height_amsl\":{\"type\":\"number\",\"desc"
    "ription\":\"Altitude determined based on the atmospheric pressure "
    "according to the standard atmosphere laws "
    "[m].\"}},\"required\":[\"orientation\"]}"
    ,
    /* example: */
    "{\"position\":{\"horizontal_accuracy\":0.810699999332428,\"crs\":{\"epsg\":497"
    "9,\"wkt\":\"GEOGCS[\\\"WGS84 / Geographic\\\",DATUM[\\\"WGS84\\\",SPHEROID[\\\"WGS8"
    "4\\\",6378137.000,298.257223563,AUTHORITY[\\\"EPSG\\\",\\\"7030\\\"]],AUTHORITY["
    "\\\"EPSG\\\",\\\"6326\\\"]],PRIMEM[\\\"Greenwich\\\",0.0000000000000000,AUTHORITY["
    "\\\"EPSG\\\",\\\"8901\\\"]],UNIT[\\\"Degree\\\",0.01745329251994329547,AUTHORITY[\\"
    "\"EPSG\\\",\\\"9102\\\"]],AXIS[\\\"Latitude\\\",NORTH],AXIS[\\\"Longitude\\\",EAST],A"
    "UTHORITY[\\\"EPSG\\\",\\\"4979\\\"]]\"},\"coordinate_3\":362.7124938964844,\"verti"
    "cal_accuracy\":1.3314999341964722,\"coordinate_2\":15.645033406,\"coordina"
    "te_1\":48.655799473},\"orientation\":{\"yaw_accuracy\":1.0094337839368757,\""
    "roll_accuracy\":0.009433783936875745,\"pitch_accuracy\":0.009433783936875"
    "745,\"roll\":3.14743073066123,\"pitch\":1.509153024827064,\"yaw\":101.872936"
    "30292045},\"barometric_height_amsl\":386.7457796227932}"
};

// Details on position and orientation sensors
const MetaDataItemInfo RDB_RIEGL_POSE_SENSORS = {
    /* name        */ "riegl.pose_sensors",
    /* title       */ "Pose Sensors",
    /* description */ "Details on position and orientation sensors",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"definitions\":{\"vector\":{\"type\":\"array\",\"maxItems\":3,"
    "\"minItems\":3,\"items\":{\"type\":\"number\",\"description\":\"Index 0=X, 1=Y, "
    "2=Z component\"}}},\"$schema\":\"http://json-schema.org/draft-04/schema#\","
    "\"description\":\"Details on position and orientation "
    "sensors\",\"title\":\"Pose Sensors\",\"properties\":{\"gyroscope\":{\"type\":\"obj"
    "ect\",\"properties\":{\"x_axis\":{\"$ref\":\"#/definitions/vector\",\"descriptio"
    "n\":\"Sensitive X axis of sensor at frame angle = 0\"},\"relative_nonlinea"
    "rity\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Relative "
    "nonlinearity, dimensionless\"},\"y_axis\":{\"$ref\":\"#/definitions/vector\","
    "\"description\":\"Sensitive Y axis of sensor at frame angle = "
    "0\"},\"origin\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensor "
    "origin in SOCS [m] at frame angle = 0\"},\"unit\":{\"type\":\"number\",\"exclu"
    "siveMinimum\":true,\"minimum\":0,\"description\":\"Unit of raw data and "
    "calibration values, 1 LSB in rad/s\"},\"z_axis\":{\"$ref\":\"#/definitions/v"
    "ector\",\"description\":\"Sensitive Z axis of sensor at frame angle = "
    "0\"},\"offset\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Value to be"
    " subtracted from raw measurement values\"}},\"required\":[\"unit\",\"x_axis\""
    ",\"y_axis\",\"z_axis\",\"offset\",\"origin\",\"relative_nonlinearity\"],\"descrip"
    "tion\":\"Gyroscope details\"},\"accelerometer\":{\"type\":\"object\",\"propertie"
    "s\":{\"x_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive X"
    " axis of sensor at frame angle = 0\"},\"relative_nonlinearity\":{\"$ref\":\""
    "#/definitions/vector\",\"description\":\"Relative nonlinearity, dimensionl"
    "ess\"},\"y_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive"
    " Y axis of sensor at frame angle = "
    "0\"},\"origin\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensor "
    "origin in SOCS [m] at frame angle = 0\"},\"unit\":{\"type\":\"number\",\"exclu"
    "siveMinimum\":true,\"minimum\":0,\"description\":\"Unit of raw data and "
    "calibration values, 1 LSB in 9.81 m/s\\u00b2\"},\"z_axis\":{\"$ref\":\"#/defi"
    "nitions/vector\",\"description\":\"Sensitive Z axis of sensor at frame "
    "angle = "
    "0\"},\"offset\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Value to be"
    " subtracted from raw measurement values\"}},\"required\":[\"unit\",\"x_axis\""
    ",\"y_axis\",\"z_axis\",\"offset\",\"origin\",\"relative_nonlinearity\"],\"descrip"
    "tion\":\"Accelerometer details\"},\"magnetic_field_sensor\":{\"type\":\"object"
    "\",\"properties\":{\"x_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":"
    "\"Sensitive X axis of sensor at frame angle = 0\"},\"relative_nonlinearit"
    "y\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Relative "
    "nonlinearity, dimensionless\"},\"y_axis\":{\"$ref\":\"#/definitions/vector\","
    "\"description\":\"Sensitive Y axis of sensor at frame angle = "
    "0\"},\"fixed\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Distortion "
    "of magnetic field caused by non-rotating scanner part\"},\"unit\":{\"type\""
    ":\"number\",\"exclusiveMinimum\":true,\"minimum\":0,\"description\":\"Unit of "
    "raw data and calibration values, 1 LSB in "
    "nT\"},\"z_axis\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Sensitive "
    "Z axis of sensor at frame angle = "
    "0\"},\"offset\":{\"$ref\":\"#/definitions/vector\",\"description\":\"Value to be"
    " subtracted from raw measurement values\"}},\"required\":[\"unit\",\"x_axis\""
    ",\"y_axis\",\"z_axis\",\"offset\",\"fixed\",\"relative_nonlinearity\"],\"descript"
    "ion\":\"Magnetic Field Sensor details\"}},\"required\":[\"gyroscope\",\"accele"
    "rometer\",\"magnetic_field_sensor\"]}"
    ,
    /* example: */
    "{\"gyroscope\":{\"x_axis\":[-121.195556640625,0.8219714164733887,0.2313031"
    "703233719],\"relative_nonlinearity\":[2.888176311444113e-07,1.0627416457"
    "9645e-07,-1.7186295080634935e-39],\"y_axis\":[-0.440765917301178,-0.7897"
    "399663925171,119.5894775390625],\"origin\":[0.026900000870227814,-0.0399"
    "9999910593033,-0.08950000256299973],\"unit\":0.00014544410805683583,\"z_a"
    "xis\":[0.555869996547699,119.22135162353516,0.467585027217865],\"offset\""
    ":[-50.92609786987305,146.15643310546875,62.4327278137207]},\"accelerome"
    "ter\":{\"x_axis\":[-15008.123046875,56.956390380859375,-60.5175666809082]"
    ",\"relative_nonlinearity\":[0.0,0.0,0.0],\"y_axis\":[-7.027288913726807,-4"
    "4.12333679199219,14952.3701171875],\"origin\":[0.026900000870227814,-0.0"
    "3999999910593033,-0.08950000256299973],\"unit\":6.666666740784422e-05,\"z"
    "_axis\":[1.639882206916809,15166.744140625,-116.99742889404297],\"offset"
    "\":[-733.3636474609375,58.969032287597656,1060.2550048828125]},\"magneti"
    "c_field_sensor\":{\"x_axis\":[-0.011162743903696537,-2.315962774446234e-0"
    "5,0.00016818844596855342],\"relative_nonlinearity\":[0.0,0.0,0.0],\"y_axi"
    "s\":[0.00027888521435670555,-0.011427424848079681,-5.204829722060822e-0"
    "5],\"fixed\":[-1576.010498046875,1596.081787109375,0.0],\"unit\":91.743118"
    "28613281,\"z_axis\":[0.00041987866279669106,7.876977906562388e-05,0.0114"
    "07104320824146],\"offset\":[-23812.052734375,5606.57666015625,2493.28125"
    "]}}"
};

// Laser pulse position modulation used for MTA resolution
const MetaDataItemInfo RDB_RIEGL_PULSE_POSITION_MODULATION = {
    /* name        */ "riegl.pulse_position_modulation",
    /* title       */ "Pulse Position Modulation",
    /* description */ "Laser pulse position modulation used for MTA resolution",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Pulse Position Modulation\",\"$schema\":\"http:/"
    "/json-schema.org/draft-04/schema#\",\"description\":\"Laser pulse position"
    " modulation used for MTA resolution\",\"properties\":{\"code_phase_mode\":{"
    "\"type\":\"integer\",\"maximum\":255,\"minimum\":0,\"description\":\"0: no "
    "synchronization, 1: toggle between 2 phases, 2: increment with phase_i"
    "ncrement\"},\"length\":{\"type\":\"integer\",\"maximum\":255,\"minimum\":0,\"descr"
    "iption\":\"Length of code\"},\"pulse_interval\":{\"type\":\"array\",\"items\":{\"t"
    "ype\":\"number\",\"minimum\":0},\"description\":\"Explicit table of the pulse "
    "position modulation used for MTA resolution. Table gives times between"
    " successive laser pulses in seconds.\"},\"num_mod_ampl\":{\"type\":\"integer"
    "\",\"maximum\":255,\"minimum\":0,\"description\":\"Number of different "
    "modulation amplitudes (2: binary modulation)\"},\"phase_step\":{\"type\":\"i"
    "nteger\",\"maximum\":255,\"minimum\":0,\"description\":\"Step width in phase "
    "of modulation code from line to "
    "line\"}},\"required\":[\"length\",\"num_mod_ampl\",\"pulse_interval\"]}"
    ,
    /* example: */
    "{\"code_phase_mode\":2,\"length\":31,\"pulse_interval\":[2.759375e-06,2.7593"
    "75e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.759375e-06,2.759375e-0"
    "6,2.821875e-06,2.759375e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.7"
    "59375e-06,2.821875e-06,2.821875e-06,2.821875e-06,2.821875e-06,2.821875"
    "e-06,2.759375e-06,2.759375e-06,2.759375e-06,2.821875e-06,2.821875e-06,"
    "2.759375e-06,2.821875e-06,2.821875e-06,2.821875e-06,2.759375e-06,2.821"
    "875e-06,2.759375e-06,2.821875e-06],\"num_mod_ampl\":2,\"phase_step\":5}"
};

// Statistics about target distance wrt. SOCS origin
const MetaDataItemInfo RDB_RIEGL_RANGE_STATISTICS = {
    /* name        */ "riegl.range_statistics",
    /* title       */ "Range Statistics",
    /* description */ "Statistics about target distance wrt. SOCS origin",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Range Statistics\",\"$schema\":\"http://json-sch"
    "ema.org/draft-04/schema#\",\"description\":\"Statistics about target "
    "distance wrt. SOCS origin\",\"properties\":{\"average\":{\"type\":\"number\",\"d"
    "escription\":\"Average "
    "value\"},\"minimum\":{\"type\":\"number\",\"description\":\"Minimum "
    "value\"},\"std_dev\":{\"type\":\"number\",\"description\":\"Standard "
    "deviation\"},\"maximum\":{\"type\":\"number\",\"description\":\"Maximum "
    "value\"}},\"required\":[\"minimum\",\"average\",\"maximum\",\"std_dev\"]}"
    ,
    /* example: */
    "{\"average\":15.49738,\"minimum\":0.919,\"std_dev\":24.349,\"maximum\":574.35}"
};

// Receiver Internals
const MetaDataItemInfo RDB_RIEGL_RECEIVER_INTERNALS = {
    /* name        */ "riegl.receiver_internals",
    /* title       */ "Receiver Internals",
    /* description */ "Receiver Internals",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"definitions\":{\"fp_table_row\":{\"type\":\"array\",\"maxIte"
    "ms\":2048,\"minItems\":1,\"items\":{\"type\":\"number\"}},\"fp_table\":{\"type\":\"o"
    "bject\",\"desription\":\"scanner internal data\",\"properties\":{\"tv\":{\"type\""
    ":\"array\",\"maxItems\":2048,\"minItems\":1,\"items\":{\"oneOf\":[{\"$ref\":\"#/def"
    "initions/fp_table_row\"},{\"type\":\"number\"}]}},\"ny\":{\"type\":\"integer\",\"m"
    "ax\":2048,\"min\":1,\"description\":\"number of y entries\"},\"ch\":{\"type\":\"in"
    "teger\",\"max\":255,\"min\":0,\"description\":\"channel "
    "number\"},\"tc\":{\"type\":\"integer\",\"max\":255,\"min\":0,\"description\":\"table"
    " data type "
    "code\"},\"nx\":{\"type\":\"integer\",\"max\":2048,\"min\":1,\"description\":\"number"
    " of x entries\"}},\"required\":[\"ch\",\"tc\",\"nx\",\"ny\",\"tv\"]},\"fp\":{\"type\":\""
    "object\",\"properties\":{\"s\":{\"type\":\"array\",\"maxItems\":256,\"minItems\":1,"
    "\"items\":{\"type\":\"array\",\"maxItems\":4096,\"minItems\":1,\"items\":{\"type\":\""
    "number\"}}},\"w\":{\"type\":\"array\",\"maxItems\":256,\"minItems\":1,\"items\":{\"t"
    "ype\":\"array\",\"maxItems\":5,\"minItems\":5,\"items\":{\"type\":\"number\"}}}},\"r"
    "equired\":[\"s\",\"w\"],\"description\":\"Fingerprint values\"}},\"$schema\":\"htt"
    "p://json-schema.org/draft-04/schema#\",\"description\":\"Receiver "
    "Internals\",\"title\":\"Receiver "
    "Internals\",\"properties\":{\"a\":{\"type\":\"array\",\"description\":\"Amplitude "
    "[dB]\",\"maxItems\":256,\"minItems\":1,\"items\":{\"type\":\"number\"}},\"t\":{\"typ"
    "e\":\"object\",\"patternProperties\":{\"^[0-9]+$\":{\"$ref\":\"#/definitions/fp\""
    ",\"description\":\"one field per channel, field name is channel index\"}},"
    "\"additionalProperties\":false},\"sr\":{\"type\":\"number\",\"description\":\"Sam"
    "ple rate [Hz]\",\"minimum\":0,\"exclusiveMinimum\":true},\"mw\":{\"type\":\"numb"
    "er\",\"description\":\"Maximum weight\",\"exclusiveMinimum\":true,\"minimum\":0"
    ",\"maximum\":4095},\"si\":{\"type\":\"number\",\"description\":\"Start index (hw_"
    "start)\",\"minimum\":0,\"maximum\":255},\"ns\":{\"type\":\"integer\",\"description"
    "\":\"Number of samples\",\"minimum\":0,\"maximum\":4095},\"tbl\":{\"type\":\"array"
    "\",\"description\":\"various internal data\",\"minItems\":1,\"items\":{\"$ref\":\""
    "#/definitions/fp_table\"}},\"ex\":{\"type\":\"object\",\"description\":\"DEPRECA"
    "TED, use 'riegl.exponential_decomposition' "
    "instead\"},\"nt\":{\"type\":\"integer\",\"description\":\"Number of "
    "traces\",\"minimum\":0,\"maximum\":255}}}"
    ,
    /* example: */
    "{\"a\":[-1.55],\"t\":{\"0\":{\"s\":[[1.23,4.56],[7.89,0.12]],\"w\":[[78,86,126,1"
    "34,31],[78,86,126,134,31]]},\"1\":{\"s\":[[1.23,4.56],[7.89,0.12]],\"w\":[[7"
    "8,86,126,134,31],[78,86,126,134,31]]}},\"sr\":7959997000.0,\"mw\":31,\"si\":"
    "48,\"ns\":400,\"tbl\":[{\"tv\":[[1,2,3,4,5],[1.1,2.2,3.3,4.4,5.5]],\"ny\":2,\"c"
    "h\":0,\"tc\":1,\"nx\":5}],\"nt\":128}"
};

// Lookup table for reflectance calculation based on amplitude and range
const MetaDataItemInfo RDB_RIEGL_REFLECTANCE_CALCULATION = {
    /* name        */ "riegl.reflectance_calculation",
    /* title       */ "Reflectance Calculation Table",
    /* description */ "Lookup table for reflectance calculation based on amplitude and range",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Reflectance Calculation Table\",\"$schema\":\"ht"
    "tp://json-schema.org/draft-04/schema#\",\"description\":\"Lookup table for"
    " reflectance calculation based on amplitude and "
    "range\",\"properties\":{\"delta\":{\"type\":\"number\",\"description\":\"Delta "
    "between table entries [m], first entry is at range = 0 m\"},\"content\":{"
    "\"type\":\"array\",\"items\":{\"type\":\"number\"},\"maxItems\":2000,\"minItems\":1,"
    "\"description\":\"Correction value [dB] to be added to the "
    "amplitude\"}},\"required\":[\"delta\",\"content\"]}"
    ,
    /* example: */
    "{\"delta\":0.150918,\"content\":[-33.01]}"
};

// Range-dependent and scan-angle-dependent correction of reflectance reading
const MetaDataItemInfo RDB_RIEGL_REFLECTANCE_CORRECTION = {
    /* name        */ "riegl.reflectance_correction",
    /* title       */ "Near-Range Reflectance Correction",
    /* description */ "Range-dependent and scan-angle-dependent correction of reflectance reading",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Near-range reflectance correction\",\"$schema\""
    ":\"http://json-schema.org/draft-04/schema#\",\"description\":\"Range-depend"
    "ent and scan-angle-dependent correction of reflectance reading\",\"prope"
    "rties\":{\"reflectance_correction_db\":{\"type\":\"array\",\"items\":{\"type\":\"a"
    "rray\",\"items\":{\"type\":\"number\",\"description\":\"columns (each value "
    "corresponds to an angle)\"},\"description\":\"rows (each array corresponds"
    " to a range)\"},\"description\":\"Near range reflectance correction in dB "
    "as a function of range over angle\"},\"line_angles_deg\":{\"type\":\"array\","
    "\"items\":{\"type\":\"number\"},\"description\":\"Angle [deg]\"},\"ranges_m\":{\"ty"
    "pe\":\"array\",\"items\":{\"type\":\"number\"},\"description\":\"Range [m]\"}},\"req"
    "uired\":[\"ranges_m\",\"line_angles_deg\",\"reflectance_correction_db\"]}"
    ,
    /* example: */
    "{\"reflectance_correction_db\":[[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0."
    "01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0"
    ".3,0.2,0.1,0.05,0.01],[0.8,0.7,0.6,0.5,0.4,0.3,0.2,0.1,0.05,0.01]],\"li"
    "ne_angles_deg\":[0.0,0.5,1.0,1.5,1.0,2.0,2.5,3.0,3.5,4.0],\"ranges_m\":[0"
    ".0,1.0,2.0,3.0]}"
};

// Scan pattern description
const MetaDataItemInfo RDB_RIEGL_SCAN_PATTERN = {
    /* name        */ "riegl.scan_pattern",
    /* title       */ "Scan Pattern",
    /* description */ "Scan pattern description",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"definitions\":{\"program\":{\"type\":\"object\",\"properties\":{\"name\":{\"type"
    "\":\"string\",\"description\":\"Name of measurement program\"},\"laser_prr\":{\""
    "type\":\"number\",\"exclusiveMinimum\":false,\"minimum\":0,\"description\":\"Las"
    "er Pulse Repetition Rate "
    "[Hz]\"}},\"required\":[\"name\"],\"description\":\"Measurement "
    "program\"}},\"title\":\"Scan Pattern\",\"$schema\":\"http://json-schema.org/dr"
    "aft-04/schema#\",\"properties\":{\"rectangular\":{\"type\":\"object\",\"properti"
    "es\":{\"theta_increment\":{\"type\":\"number\",\"maximum\":90.0,\"minimum\":0.0,\""
    "description\":\"Increment of theta angle in SOCS [deg]\"},\"phi_start\":{\"t"
    "ype\":\"number\",\"maximum\":360.0,\"minimum\":0.0,\"description\":\"Start phi "
    "angle in SOCS [deg]\"},\"program\":{\"$ref\":\"#/definitions/program\"},\"thet"
    "a_stop\":{\"type\":\"number\",\"maximum\":180.0,\"minimum\":0.0,\"description\":\""
    "Stop theta angle in SOCS [deg]\"},\"phi_stop\":{\"type\":\"number\",\"maximum\""
    ":720.0,\"minimum\":0.0,\"description\":\"Stop phi angle in SOCS [deg]\"},\"th"
    "eta_start\":{\"type\":\"number\",\"maximum\":180.0,\"minimum\":0.0,\"description"
    "\":\"Start theta angle in SOCS [deg]\"},\"phi_increment\":{\"type\":\"number\","
    "\"maximum\":90.0,\"minimum\":0.0,\"description\":\"Increment of phi angle in "
    "SOCS [deg]\"}},\"required\":[\"phi_start\",\"phi_stop\",\"phi_increment\",\"thet"
    "a_start\",\"theta_stop\",\"theta_increment\"],\"description\":\"Rectangular "
    "Field Of View Scan Pattern\"},\"segments\":{\"type\":\"object\",\"properties\":"
    "{\"list\":{\"type\":\"array\",\"items\":{\"type\":\"object\",\"properties\":{\"stop\":"
    "{\"type\":\"number\",\"maximum\":720.0,\"minimum\":0.0,\"description\":\"Stop "
    "angle in SOCS [deg]\"},\"increment\":{\"type\":\"number\",\"maximum\":90.0,\"min"
    "imum\":0.0,\"description\":\"Increment of angle in SOCS [deg]\"},\"start\":{\""
    "type\":\"number\",\"maximum\":360.0,\"minimum\":0.0,\"description\":\"Start "
    "angle in SOCS "
    "[deg]\"}},\"required\":[\"start\",\"stop\",\"increment\"],\"description\":\"Line "
    "Scan Segment\"}},\"program\":{\"$ref\":\"#/definitions/program\"}},\"required\""
    ":[\"list\"],\"description\":\"Segmented Line Scan Pattern\"},\"line\":{\"type\":"
    "\"object\",\"properties\":{\"stop\":{\"type\":\"number\",\"maximum\":720.0,\"minimu"
    "m\":0.0,\"description\":\"Stop angle in SOCS [deg]\"},\"program\":{\"$ref\":\"#/"
    "definitions/program\"},\"increment\":{\"type\":\"number\",\"maximum\":90.0,\"min"
    "imum\":0.0,\"description\":\"Increment of angle in SOCS [deg]\"},\"start\":{\""
    "type\":\"number\",\"maximum\":360.0,\"minimum\":0.0,\"description\":\"Start "
    "angle in SOCS "
    "[deg]\"}},\"required\":[\"start\",\"stop\",\"increment\"],\"description\":\"Line "
    "Scan Pattern\"}},\"description\":\"Scan pattern description\"}"
    ,
    /* example: */
    "{\"rectangular\":{\"theta_increment\":0.04,\"phi_start\":45.0,\"program\":{\"na"
    "me\":\"High Speed\",\"laser_prr\":100000.0},\"theta_stop\":130.0,\"phi_stop\":2"
    "70.0,\"theta_start\":30.0,\"phi_increment\":0.04}}"
};

// Details about laser shot files
const MetaDataItemInfo RDB_RIEGL_SHOT_INFO = {
    /* name        */ "riegl.shot_info",
    /* title       */ "Shot Information",
    /* description */ "Details about laser shot files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Shot Information\",\"$schema\":\"http://json-sch"
    "ema.org/draft-04/schema#\",\"properties\":{\"shot_file\":{\"type\":\"object\",\""
    "properties\":{\"file_uuid\":{\"type\":\"string\",\"description\":\"File's "
    "Universally Unique Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Shot file "
    "extension, without the leading "
    "dot\"}},\"required\":[\"file_extension\"]}},\"description\":\"Details about "
    "laser shot files\"}"
    ,
    /* example: */
    "{\"shot_file\":{\"file_uuid\":\"26a00815-67c0-4bff-8fe8-c577378fe663\",\"file"
    "_extension\":\"sodx\"}}"
};

// Point filters applied in addition to the application-defined filters
const MetaDataItemInfo RDB_RIEGL_STORED_FILTERS = {
    /* name        */ "riegl.stored_filters",
    /* title       */ "Stored Filters",
    /* description */ "Point filters applied in addition to the application-defined filters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Stored filters\",\"$schema\":\"http://json-schem"
    "a.org/draft-04/schema#\",\"description\":\"Point filters applied in "
    "addition to the application-defined filters\",\"properties\":{\"filters\":{"
    "\"type\":\"array\",\"items\":{\"type\":\"object\",\"properties\":{\"filter\":{\"type\""
    ":\"string\",\"description\":\"The RDB filter string to apply (e.g. when "
    "reading points or index), details see documentation of function "
    "select()\"},\"title\":{\"type\":\"string\",\"description\":\"A short filter "
    "title (e.g. for display in a selection "
    "list)\"},\"activated\":{\"type\":\"boolean\",\"description\":\"Apply ('true') or"
    " ignore ('false') this "
    "filter\"},\"description\":{\"type\":\"string\",\"description\":\"A brief "
    "description of the filter (e.g. for display in a tooltip)\"}},\"required"
    "\":[\"activated\",\"title\",\"description\",\"filter\"],\"description\":\"Point "
    "filter definition\"},\"description\":\"List of point "
    "filters\"},\"activated\":{\"type\":\"boolean\",\"description\":\"Apply ('true') "
    "or ignore ('false') all filters\"}},\"required\":[\"activated\",\"filters\"]}"
    ,
    /* example: */
    "{\"filters\":[{\"filter\":\"riegl.mta_uncertain_point == 0\",\"title\":\"Ignore"
    " uncertain points from MTA "
    "resolution\",\"activated\":false,\"description\":\"Ignore points with "
    "uncertain MTA zone "
    "assignment\"},{\"filter\":\"riegl.dyntrig_uncertain_point == "
    "0\",\"title\":\"Ignore points below dynamic trigger "
    "level\",\"activated\":false,\"description\":\"Ignore points with an echo "
    "signal amplitude below the dynamic "
    "trigger\"},{\"filter\":\"riegl.point_outside_aabb_bocs == "
    "0\",\"title\":\"Ignore points outside outer "
    "AABB\",\"activated\":false,\"description\":\"Ignore points that are outside "
    "the outer AABB in BOCS\"},{\"filter\":\"riegl.point_inside_aabb_bocs == "
    "0\",\"title\":\"Ignore points inside inner "
    "AABB\",\"activated\":false,\"description\":\"Ignore points that are inside "
    "the inner AABB in BOCS\"}],\"activated\":true}"
};

// Details of major system components like lidar sensors, cameras and navigation devices
const MetaDataItemInfo RDB_RIEGL_SYSTEM_DESCRIPTION = {
    /* name        */ "riegl.system_description",
    /* title       */ "System Description",
    /* description */ "Details of major system components like lidar sensors, cameras and navigation devices",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"System Description\",\"$schema\":\"http://json-s"
    "chema.org/draft-04/schema#\",\"description\":\"Details of major system "
    "components like lidar sensors, cameras and navigation devices\",\"proper"
    "ties\":{\"version\":{\"type\":\"string\",\"description\":\"Document format "
    "version\"},\"author\":{\"type\":\"string\",\"description\":\"Name of the author "
    "that created the document\"},\"$class\":{\"type\":\"string\",\"enum\":[\"Documen"
    "t\"],\"description\":\"Object class "
    "name\"},\"system\":{\"type\":\"object\",\"description\":\"The actual system "
    "description, details see documentation of RIEGL System "
    "Description\"},\"timestamp\":{\"type\":\"string\",\"description\":\"Date and "
    "time of creation (e.g. 2019-06-19T13:32:10+02:00)\"}},\"required\":[\"$cla"
    "ss\",\"version\",\"author\",\"timestamp\",\"system\"]}"
    ,
    /* example: */
    "{\"version\":\"1.2.1\",\"author\":\"RIEGL LMS GmbH, "
    "Austria\",\"$class\":\"Document\",\"system\":{\"details\":\"see documentation of"
    " RIEGL System Description\"},\"timestamp\":\"2022-09-30T11:56:26+00:00\"}"
};

// Conversion of background radiation raw values to temperatures in °C
const MetaDataItemInfo RDB_RIEGL_TEMPERATURE_CALCULATION = {
    /* name        */ "riegl.temperature_calculation",
    /* title       */ "Temperature Calculation Table",
    /* description */ "Conversion of background radiation raw values to temperatures in °C",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"definitions\":{\"conversion_table\":{\"type\":\"object\",\"p"
    "roperties\":{\"value\":{\"type\":\"array\",\"items\":{\"type\":\"number\"},\"descrip"
    "tion\":\"LSB [1]\"},\"temperature\":{\"type\":\"array\",\"items\":{\"type\":\"number"
    "\"},\"description\":\"Temperature [\\u00b0C]\"}},\"required\":[\"value\",\"temper"
    "ature\"]}},\"$schema\":\"http://json-schema.org/draft-04/schema#\",\"descrip"
    "tion\":\"Conversion of background radiation raw values to temperatures "
    "in \\u00b0C\",\"title\":\"Temperature Calculation Table\",\"properties\":{\"InG"
    "aAs_Si_Difference\":{\"$ref\":\"#/definitions/conversion_table\",\"descripti"
    "on\":\"Conversion table for InGaAs - Si difference\"},\"InGaAs\":{\"$ref\":\"#"
    "/definitions/conversion_table\",\"description\":\"Conversion table for "
    "InGaAs channel\"},\"Si\":{\"$ref\":\"#/definitions/conversion_table\",\"descri"
    "ption\":\"Conversion table for Si channel\"}}}"
    ,
    /* example: */
    "{\"InGaAs_Si_Difference\":{\"value\":[1000.0,1100.090029602954,1200.044251"
    "83874,1300.1342814416948,1400.0885036774805,1500.0427259132668,1600.13"
    "27555162209,1700.0869777520065,1800.0411999877924],\"temperature\":[1749"
    ".977111117893,1749.977111117893,1749.977111117893,1749.977111117893,17"
    "49.977111117893,1749.977111117893,1744.7813348796044,1681.997131260109"
    "2,1622.3944822534868]},\"InGaAs\":{\"value\":[0.0,64.00097659230323,128.00"
    "19531846065,192.0029297769097,256.0039063692129,320.00488296151616,384"
    ".0058595538194,448.0068361461226,512.0078127384259],\"temperature\":[307"
    ".22196722535614,309.1153478247277,311.1188086915047,313.10025350480055"
    ",315.2137946389828,317.2172555057597,319.2207163725366,321.20216118583"
    "25,323.3157023200148]},\"Si\":{\"value\":[0.0,64.00097659230323,128.001953"
    "1846065,192.0029297769097,256.0039063692129,320.00488296151616,384.005"
    "8595538194,448.0068361461226,512.0078127384259],\"temperature\":[546.300"
    "048828125,548.8164051212026,551.3143938500972,554.0144257850053,556.60"
    "4252334815,559.2124464488079,561.8022729986177,564.4104671126105,567.0"
    "002936624203]}}"
};

// Base of timestamps (epoch)
const MetaDataItemInfo RDB_RIEGL_TIME_BASE = {
    /* name        */ "riegl.time_base",
    /* title       */ "Time Base",
    /* description */ "Base of timestamps (epoch)",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Time Base\",\"$schema\":\"http://json-schema.org"
    "/draft-04/schema#\",\"description\":\"Base of timestamps "
    "(epoch)\",\"properties\":{\"epoch\":{\"type\":\"string\",\"description\":\"Date "
    "and time of timestamp '0' as proposed by RFC 3339 (e.g. 2015-10-27T00:"
    "00:00+01:00).\"},\"system\":{\"type\":\"string\",\"enum\":[\"unknown\",\"UTC\",\"GPS"
    "\"],\"description\":\"Time system (time standard)\"},\"source\":{\"type\":\"stri"
    "ng\",\"enum\":[\"unknown\",\"RTC\",\"GNSS\"],\"description\":\"Timestamp "
    "source\"}},\"required\":[\"epoch\",\"source\"]}"
    ,
    /* example: */
    "{\"epoch\":\"2015-10-27T00:00:00+00:00\",\"system\":\"UTC\",\"source\":\"GNSS\"}"
};

// Details about position+orientation files
const MetaDataItemInfo RDB_RIEGL_TRAJECTORY_INFO = {
    /* name        */ "riegl.trajectory_info",
    /* title       */ "Trajectory Information",
    /* description */ "Details about position+orientation files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Trajectory Information\",\"$schema\":\"http://js"
    "on-schema.org/draft-04/schema#\",\"description\":\"Details about "
    "position+orientation files\",\"properties\":{\"field_of_application\":{\"typ"
    "e\":\"string\",\"enum\":[\"unknown\",\"SLS\",\"TLS\",\"KLS\",\"MLS\",\"ULS\",\"ALS\",\"BLS"
    "\",\"ILS\"],\"description\":\"Field of "
    "application\"},\"location\":{\"type\":\"string\",\"description\":\"Project "
    "location, e.g. city/state/country\"},\"navigation_frame\":{\"type\":\"string"
    "\",\"enum\":[\"unknown\",\"NED\",\"ENU\"],\"description\":\"Navigation frame (NED:"
    " North-East-Down, ENU: "
    "East-North-Up)\"},\"software\":{\"type\":\"string\",\"description\":\"Software "
    "that calculated the trajectory (this may be the same or different "
    "software than the one that created the "
    "file)\"},\"project\":{\"type\":\"string\",\"description\":\"Project name\"},\"time"
    "_interval\":{\"type\":\"object\",\"properties\":{\"average\":{\"type\":\"number\",\""
    "description\":\"Average time interval "
    "[s]\"},\"minimum\":{\"type\":\"number\",\"description\":\"Minimum time interval "
    "[s]\"},\"std_dev\":{\"type\":\"number\",\"description\":\"Standard deviation of "
    "intervals [s]\"},\"maximum\":{\"type\":\"number\",\"description\":\"Maximum time"
    " interval [s]\"}},\"required\":[\"minimum\",\"average\",\"maximum\",\"std_dev\"],"
    "\"description\":\"Time interval "
    "statistics\"},\"company\":{\"type\":\"string\",\"description\":\"Company "
    "name\"},\"device\":{\"type\":\"string\",\"description\":\"Navigation device, "
    "e.g. "
    "name/type/serial\"},\"settings\":{\"type\":\"string\",\"description\":\"Settings"
    " used to calculate the trajectory (descriptive "
    "text)\"}},\"required\":[\"time_interval\",\"navigation_frame\"]}"
    ,
    /* example: */
    "{\"field_of_application\":\"MLS\",\"location\":\"Horn\",\"navigation_frame\":\"NE"
    "D\",\"software\":\"Navigation Software XYZ\",\"project\":\"Campaign 3\",\"time_i"
    "nterval\":{\"average\":0.00500053,\"minimum\":0.00500032,\"std_dev\":5.51e-07"
    ",\"maximum\":0.005004883},\"company\":\"RIEGL LMS\",\"device\":\"IMU Model "
    "12/1, Serial# 12345\",\"settings\":\"default\"}"
};

// Trigger-Timestamping-Unit/IP configuration
const MetaDataItemInfo RDB_RIEGL_TTIP_CONFIGURATION = {
    /* name        */ "riegl.ttip_configuration",
    /* title       */ "TTIP Configuration",
    /* description */ "Trigger-Timestamping-Unit/IP configuration",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"TTIP Configuration\",\"$schema\":\"http://json-s"
    "chema.org/draft-04/schema#\",\"description\":\"Trigger-Timestamping-Unit/I"
    "P configuration\",\"properties\":{\"output_usage\":{\"type\":\"integer\",\"minim"
    "um\":0,\"description\":\"0 .. no output, 1 .. output derived from internal"
    " clock, 2 .. output derived from dmi, 3 .. output derived from "
    "external signal, 4 .. output static low, 5 .. output static high\"},\"in"
    "_max_delay\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"maximum delay"
    " to output pulse before fake event is generated [0.1 msec], zero "
    "indicates that no fake events are generated\"},\"ext_delay\":{\"type\":\"int"
    "eger\",\"minimum\":0,\"description\":\"external trigger, time delay [0.1 "
    "msec]\"},\"in_polarity\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"0 "
    ".. positive edge, 1 .. negative edge\"},\"dmi_min_time\":{\"type\":\"integer"
    "\",\"minimum\":0,\"description\":\"dmi, minimum time interval between "
    "trigger events [0.1 msec]\"},\"out_num_pulses\":{\"type\":\"integer\",\"minimu"
    "m\":0,\"description\":\"number of output pulses to be generated, 0 .. infi"
    "nite\"},\"dmi_max_time\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"dmi"
    ", maximum time interval between trigger events [0.1 "
    "msec]\"},\"dmi_dist_per_tick\":{\"type\":\"number\",\"description\":\"dmi, "
    "distance per tick, just informative [m]\"},\"num_channel\":{\"type\":\"integ"
    "er\",\"minimum\":0,\"description\":\"number of input/output channels\"},\"out_"
    "duration\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"output pulse "
    "duration [0.1 "
    "msec]\"},\"channel\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"ID of "
    "input/output "
    "channel\"},\"dmi_incr\":{\"type\":\"integer\",\"description\":\"dmi, increment "
    "in "
    "ticks\"},\"ext_channel\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"ID "
    "of channel used as external trigger input, 32 indicates "
    "none\"},\"input_usage\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"0 .."
    " deactivated, 1 .. just detecting and timestamping\"},\"output_descr\":{\""
    "type\":\"string\",\"description\":\"descriptive string\"},\"out_delay\":{\"type\""
    ":\"integer\",\"minimum\":0,\"description\":\"output pulse initial delay after"
    " start [0.1 msec]\"},\"ttip_version\":{\"type\":\"integer\",\"minimum\":0,\"desc"
    "ription\":\"following main.sub.ss.sss\"},\"out_polarity\":{\"type\":\"integer\""
    ",\"minimum\":0,\"description\":\"0 .. positive edge, 1 .. negative "
    "edge\"},\"input_descr\":{\"type\":\"string\",\"description\":\"descriptive "
    "string\"},\"ext_signal\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"0 "
    ".. use input signal, 1 .. use output signal of channel\"},\"ext_subdivid"
    "er\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"reduces the "
    "frequency, default "
    "1\"},\"ext_bitmask\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"defines"
    " which of the internal pulse generators are to be started\"},\"in_min_du"
    "ration\":{\"type\":\"integer\",\"minimum\":0,\"description\":\"input signals "
    "with smaller pulse durations are ignored [0.1 msec]\"},\"out_interval\":{"
    "\"type\":\"integer\",\"minimum\":0,\"description\":\"output pulse interval [0.1"
    " msec]\"},\"in_max_duration\":{\"type\":\"integer\",\"minimum\":0,\"description\""
    ":\"stops measurement of pulse duration of input signal [0.1 msec]\"}},\"r"
    "equired\":[\"ttip_version\",\"num_channel\",\"ext_channel\",\"ext_signal\",\"ext"
    "_delay\",\"ext_subdivider\",\"ext_bitmask\",\"dmi_incr\",\"dmi_min_time\",\"dmi_"
    "max_time\",\"dmi_dist_per_tick\",\"channel\",\"output_descr\",\"input_descr\",\""
    "output_usage\",\"input_usage\",\"out_polarity\",\"out_duration\",\"out_interva"
    "l\",\"out_delay\",\"out_num_pulses\",\"in_polarity\",\"in_min_duration\",\"in_ma"
    "x_duration\",\"in_max_delay\"]}"
    ,
    /* example: */
    "{\"output_usage\":1,\"in_max_delay\":9990,\"ext_delay\":0,\"in_polarity\":0,\"d"
    "mi_min_time\":0,\"out_num_pulses\":1,\"dmi_max_time\":0,\"dmi_dist_per_tick\""
    ":0.0,\"num_channel\":9,\"out_duration\":300,\"channel\":0,\"dmi_incr\":0,\"ext_"
    "channel\":32,\"input_usage\":1,\"output_descr\":\"Port 1 - Trigger\",\"out_del"
    "ay\":0,\"ttip_version\":1,\"out_polarity\":0,\"input_descr\":\"Port 1 - Exposu"
    "re\",\"ext_signal\":0,\"ext_subdivider\":1,\"ext_bitmask\":0,\"in_min_duration"
    "\":0,\"out_interval\":10000,\"in_max_duration\":10000}"
};

// Details about vertex file
const MetaDataItemInfo RDB_RIEGL_VERTEX_INFO = {
    /* name        */ "riegl.vertex_info",
    /* title       */ "Vertex Information",
    /* description */ "Details about vertex file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Vertex Information\",\"$schema\":\"http://json-s"
    "chema.org/draft-04/schema#\",\"properties\":{\"vertex_file\":{\"type\":\"objec"
    "t\",\"properties\":{\"file_uuid\":{\"type\":\"string\",\"description\":\"File's "
    "Universally Unique Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Vertex file "
    "extension, without the leading "
    "dot\"}},\"required\":[\"file_extension\"]}},\"description\":\"Details about "
    "vertex file\"}"
    ,
    /* example: */
    "{\"vertex_file\":{\"file_uuid\":\"51534d95-d71f-4f36-ae1a-3e63a21fd1c7\",\"fi"
    "le_extension\":\"vtx\"}}"
};

// Details about the voxels contained in the file
const MetaDataItemInfo RDB_RIEGL_VOXEL_INFO = {
    /* name        */ "riegl.voxel_info",
    /* title       */ "Voxel Information",
    /* description */ "Details about the voxels contained in the file",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Voxel Information\",\"$schema\":\"http://json-sc"
    "hema.org/draft-04/schema#\",\"description\":\"Details about the voxels "
    "contained in the file\",\"definitions\":{\"edge_length\":{\"type\":\"number\",\""
    "exclusiveMinimum\":true,\"minimum\":0,\"description\":\"Length of voxel edge"
    " [m].\"},\"shape_thresholds\":{\"type\":\"object\",\"properties\":{\"plane\":{\"ty"
    "pe\":\"number\",\"minimum\":0,\"exclusiveMinimum\":true,\"maximum\":1,\"descript"
    "ion\":\"If the smallest eigenvalue is smaller than the median eigenvalue"
    " * plane_threshold, the voxel is considered a plane.\",\"exclusiveMaximu"
    "m\":true},\"line\":{\"type\":\"number\",\"exclusiveMinimum\":true,\"minimum\":1,\""
    "description\":\"If the biggest eigenvalue is bigger than the median "
    "eigenvalue * line_threshold, the voxel is considered a "
    "line.\"}},\"required\":[\"plane\",\"line\"],\"description\":\"Thresholds used to"
    " compute the voxel's shape_id value.\"},\"voxel_size\":{\"items\":{\"$ref\":\""
    "#/definitions/edge_length\"},\"maxItems\":3,\"minItems\":3,\"type\":\"array\",\""
    "description\":\"Size of voxels.\"},\"voxel_origin_point\":{\"items\":{\"type\":"
    "\"number\"},\"maxItems\":3,\"minItems\":3,\"type\":\"array\",\"description\":\"Orig"
    "in point for all voxel indices in voxel CRS.\"},\"voxel_size_cubic\":{\"ty"
    "pe\":\"number\",\"$ref\":\"#/definitions/edge_length\"},\"voxel_origin_enum\":{"
    "\"enum\":[\"center\",\"corner\"],\"default\":\"corner\",\"description\":\"Defines "
    "whether the voxel's center or a corner is placed on CRS origin <tt>(0/"
    "0/0)</tt>.\"},\"voxel_type\":{\"enum\":[\"center\",\"centroid\",\"index\"],\"defau"
    "lt\":\"centroid\",\"description\":\"Whether a point in a voxel represents "
    "its center or its centroid. If type is <tt>index</tt> there is no "
    "point but only an integer voxel index.\"}},\"oneOf\":[{\"additionalPropert"
    "ies\":false,\"properties\":{\"shape_thresholds\":{\"$ref\":\"#/definitions/sha"
    "pe_thresholds\"},\"voxel_origin\":{\"$ref\":\"#/definitions/voxel_origin_enu"
    "m\"},\"size\":{\"oneOf\":[{\"$ref\":\"#/definitions/voxel_size\"},{\"$ref\":\"#/de"
    "finitions/voxel_size_cubic\"}],\"description\":\"Size of voxels in file "
    "coordinate system.\"},\"voxel_type\":{\"$ref\":\"#/definitions/voxel_type\"}}"
    ",\"required\":[\"size\",\"voxel_origin\",\"voxel_type\"]},{\"additionalProperti"
    "es\":false,\"properties\":{\"shape_thresholds\":{\"$ref\":\"#/definitions/shap"
    "e_thresholds\"},\"size\":{\"$ref\":\"#/definitions/voxel_size\",\"description\""
    ":\"Size of voxels in file coordinate system.\"},\"size_llcs\":{\"$ref\":\"#/d"
    "efinitions/voxel_size\",\"description\":\"Size of voxels in a locally "
    "levelled cartesian coordinate system (xyz). This is only used for "
    "voxels based on a map projection.\"},\"voxel_origin\":{\"oneOf\":[{\"$ref\":\""
    "#/definitions/voxel_origin_enum\"},{\"$ref\":\"#/definitions/voxel_origin_"
    "point\",\"description\":\"The base point of the voxel grid. Used together "
    "with <tt>voxel_size</tt> and <tt>voxel_index</tt> to compute actual "
    "point coordinates.\"}]},\"voxel_type\":{\"$ref\":\"#/definitions/voxel_type\""
    "},\"reference_point\":{\"items\":{\"type\":\"number\",\"minimum\":-180,\"maximum\""
    ":180},\"maxItems\":2,\"minItems\":2,\"type\":\"array\",\"description\":\"Point in"
    " WGS84 geodetic decimal degree (EPSG:4326) that was used to compute "
    "the projection distortion parameters. The coefficient order is "
    "latitude, longitude. Only voxels with corresponding geo_tag, "
    "voxel_size and reference_point can be reliably processed together. "
    "This entry is available for voxel files in projected CRS only.\"}},\"req"
    "uired\":[\"reference_point\",\"size_llcs\",\"size\",\"voxel_origin\",\"voxel_typ"
    "e\"]}]}"
    ,
    /* example: */
    "{\"shape_thresholds\":{\"plane\":0.16,\"line\":6},\"size\":[0.5971642834779395"
    ",0.5971642834779395,0.5143705304787237],\"size_llcs\":[0.515657525289117"
    "1,0.5130835356683303,0.5143705304787237],\"voxel_origin\":\"corner\",\"voxe"
    "l_type\":\"centroid\",\"reference_point\":[48,16]}"
};

// Settings for waveform averaging
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS = {
    /* name        */ "riegl.waveform_averaging_settings",
    /* title       */ "Waveform Averaging Settings",
    /* description */ "Settings for waveform averaging",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Waveform Averaging Settings\",\"$schema\":\"http"
    "://json-schema.org/draft-04/schema#\",\"description\":\"Settings for "
    "waveform averaging\",\"properties\":{\"num_shots\":{\"type\":\"integer\",\"minim"
    "um\":1,\"description\":\"Number of consecutive shots to be used for averag"
    "ing.\"},\"mta_zone\":{\"type\":\"integer\",\"minimum\":1,\"description\":\"Fixed "
    "MTA zone for averaging.\"},\"trim\":{\"type\":\"number\",\"maximum\":0.5,\"minim"
    "um\":0,\"default\":0,\"description\":\"Percentage for robust "
    "averaging.\"}},\"required\":[\"num_shots\",\"mta_zone\"]}"
    ,
    /* example: */
    "{\"num_shots\":7,\"mta_zone\":1,\"trim\":0.05}"
};

// Details about waveform files
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_INFO = {
    /* name        */ "riegl.waveform_info",
    /* title       */ "Waveform Information",
    /* description */ "Details about waveform files",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Waveform Information\",\"$schema\":\"http://json"
    "-schema.org/draft-04/schema#\",\"description\":\"Details about waveform fi"
    "les\",\"properties\":{\"range_offset_m\":{\"type\":\"number\",\"description\":\"Ca"
    "librated device specific range offset for waveform analysis by system "
    "response fitting in meters.\"},\"sample_block_file\":{\"type\":\"object\",\"pr"
    "operties\":{\"file_uuid\":{\"type\":\"string\",\"description\":\"File's "
    "Universally Unique Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Sample block "
    "file extension, without the leading dot\"}},\"required\":[\"file_extension"
    "\"]},\"range_offset_waveform_samples_m\":{\"type\":\"number\",\"description\":\""
    "Calibrated device specific range offset for waveform samples in meters"
    ".\"},\"sample_data_files\":{\"type\":\"array\",\"items\":{\"type\":\"object\",\"prop"
    "erties\":{\"laser_wavelength\":{\"type\":\"number\",\"exclusiveMinimum\":false,"
    "\"minimum\":0,\"description\":\"Laser wavelength in meters (0 = unknown)\"},"
    "\"delta_st\":{\"type\":\"number\",\"description\":\"reserved\"},\"channel\":{\"type"
    "\":\"integer\",\"minimum\":0,\"description\":\"Sample block channel number "
    "(255 = invalid)\",\"exclusiveMinimum\":false,\"maximum\":255,\"exclusiveMaxi"
    "mum\":false},\"sample_bits\":{\"type\":\"integer\",\"minimum\":0,\"description\":"
    "\"Bitwidth of samples (e.g. 10 bit, 12 bit)\",\"exclusiveMinimum\":false,\""
    "maximum\":32,\"exclusiveMaximum\":false},\"file_uuid\":{\"type\":\"string\",\"de"
    "scription\":\"File's Universally Unique Identifier (RFC "
    "4122)\"},\"file_extension\":{\"type\":\"string\",\"description\":\"Sample data "
    "file extension, without the leading dot\"},\"sample_interval\":{\"type\":\"n"
    "umber\",\"exclusiveMinimum\":false,\"minimum\":0,\"description\":\"Sampling "
    "interval in "
    "seconds\"},\"channel_name\":{\"type\":\"string\",\"description\":\"Sample block "
    "channel name\"}},\"required\":[\"channel\",\"channel_name\",\"sample_interval\""
    ",\"sample_bits\",\"laser_wavelength\",\"delta_st\",\"file_extension\"]}}},\"req"
    "uired\":[\"sample_block_file\",\"sample_data_files\"]}"
    ,
    /* example: */
    "{\"range_offset_m\":3.1415,\"sample_block_file\":{\"file_uuid\":\"93a03615-66"
    "c0-4bea-8ff8-c577378fe660\",\"file_extension\":\"sbx\"},\"range_offset_wavef"
    "orm_samples_m \":7.283,\"sample_data_files\":[{\"laser_wavelength\":0,\"delt"
    "a_st\":0,\"channel\":0,\"sample_interval\":1.00503e-09,\"file_uuid\":\"da08441"
    "3-e3e8-4655-a122-071de8490d8e\",\"file_extension\":\"sp0\",\"sample_bits\":12"
    ",\"channel_name\":\"high_power\"},{\"laser_wavelength\":0,\"delta_st\":0,\"chan"
    "nel\":1,\"sample_interval\":1.00503e-09,\"file_uuid\":\"93585b5e-5ea9-43a1-9"
    "47b-e7ba3be642d2\",\"file_extension\":\"sp1\",\"sample_bits\":12,\"channel_nam"
    "e\":\"low_power\"},{\"laser_wavelength\":0,\"delta_st\":0,\"channel\":5,\"sample"
    "_interval\":1.00503e-09,\"file_uuid\":\"9d2298c4-1036-464f-b5cb-1cf8e517f3"
    "a0\",\"file_extension\":\"sp5\",\"sample_bits\":12,\"channel_name\":\"wwf\"}]}"
};

// Scanner settings for waveform output
const MetaDataItemInfo RDB_RIEGL_WAVEFORM_SETTINGS = {
    /* name        */ "riegl.waveform_settings",
    /* title       */ "Waveform Settings",
    /* description */ "Scanner settings for waveform output",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"array\",\"items\":{\"type\":\"object\",\"properties\":{\"logic_expressi"
    "on\":{\"type\":\"string\",\"description\":\"Logic expression of smart "
    "waveforms "
    "filter\"},\"pass_dev_greater\":{\"type\":\"integer\",\"description\":\"Threshold"
    " for deviation greater than "
    "[1]\"},\"pass_rng_greater\":{\"type\":\"number\",\"description\":\"Threshold for"
    " range greater than "
    "[m]\"},\"smart_enabled\":{\"type\":\"boolean\",\"description\":\"Smart waveform "
    "output enabled\"},\"enabled\":{\"type\":\"boolean\",\"description\":\"Waveform "
    "output "
    "enabled\"},\"pass_ampl_less\":{\"type\":\"number\",\"description\":\"Threshold "
    "for amplitude less than "
    "[dB]\"},\"pass_ampl_greater\":{\"type\":\"number\",\"description\":\"Threshold "
    "for amplitude greater than "
    "[dB]\"},\"channel_idx_mask\":{\"type\":\"integer\",\"description\":\"Bit mask "
    "for channels which belong to sbl_name: Channel 0 = Bit0, Channel 1 = "
    "Bit1, ...\"},\"sbl_name\":{\"type\":\"string\",\"description\":\"Name of sample "
    "block, e.g.: wfm, "
    "wwf\"},\"pass_dev_less\":{\"type\":\"integer\",\"description\":\"Threshold for "
    "deviation less than "
    "[1]\"},\"pass_rng_less\":{\"type\":\"number\",\"description\":\"Threshold for "
    "range less than [m]\"}},\"required\":[\"sbl_name\",\"enabled\",\"channel_idx_m"
    "ask\"]},\"title\":\"Waveform Settings\",\"$schema\":\"http://json-schema.org/d"
    "raft-04/schema#\",\"description\":\"Scanner settings for waveform output\"}"
    ,
    /* example: */
    "[{\"channel_idx_mask\":11,\"pass_rng_greater\":9.27,\"smart_enabled\":true,\""
    "enabled\":true,\"pass_ampl_less\":5.0,\"pass_ampl_greater\":1.0,\"sbl_name\":"
    "\"wfm\",\"pass_rng_less\":13.11},{\"enabled\":false,\"channel_idx_mask\":32,\"s"
    "bl_name\":\"wwf\"}]"
};

// Window analysis data estimated from scandata and resulting filter parameters
const MetaDataItemInfo RDB_RIEGL_WINDOW_ANALYSIS = {
    /* name        */ "riegl.window_analysis",
    /* title       */ "Window Analysis",
    /* description */ "Window analysis data estimated from scandata and resulting filter parameters",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Window Analysis\",\"$schema\":\"http://json-sche"
    "ma.org/draft-04/schema#\",\"description\":\"Window analysis data estimated"
    " from scandata and resulting filter parameters\",\"properties\":{\"result\""
    ":{\"type\":\"object\",\"properties\":{\"amplitude_mean\":{\"type\":\"array\",\"desc"
    "ription\":\"[dB]\",\"items\":{\"type\":\"number\"}},\"range_mean\":{\"type\":\"array"
    "\",\"description\":\"[m]\",\"items\":{\"type\":\"number\"}},\"angle\":{\"type\":\"arra"
    "y\",\"description\":\"[deg]\",\"items\":{\"type\":\"number\"}},\"timestamp\":{\"type"
    "\":\"array\",\"description\":\"[s]\",\"items\":{\"type\":\"number\"}},\"amplitude_si"
    "gma\":{\"type\":\"array\",\"description\":\"[dB]\",\"items\":{\"type\":\"number\"}},\""
    "amplitude_offset\":{\"type\":\"array\",\"description\":\"[dB]\",\"items\":{\"type\""
    ":\"number\"}},\"range_sigma\":{\"type\":\"array\",\"description\":\"[m]\",\"items\":"
    "{\"type\":\"number\"}}},\"required\":[\"angle\",\"range_mean\",\"range_sigma\",\"am"
    "plitude_mean\",\"amplitude_sigma\",\"amplitude_offset\"]},\"settings\":{\"type"
    "\":\"object\",\"properties\":{\"amplitude\":{\"type\":\"object\",\"properties\":{\"a"
    "dditive_value\":{\"type\":\"number\"},\"sigma_factor\":{\"type\":\"number\"}},\"re"
    "quired\":[\"sigma_factor\",\"additive_value\"]},\"range\":{\"type\":\"object\",\"p"
    "roperties\":{\"additive_value\":{\"type\":\"number\"},\"sigma_factor\":{\"type\":"
    "\"number\"}},\"required\":[\"sigma_factor\",\"additive_value\"]}},\"required\":["
    "\"range\",\"amplitude\"]},\"filter\":{\"type\":\"object\",\"properties\":{\"range_m"
    "in\":{\"type\":\"array\",\"description\":\"[m]\",\"items\":{\"type\":\"number\"}},\"an"
    "gle\":{\"type\":\"array\",\"description\":\"[deg]\",\"items\":{\"type\":\"number\"}},"
    "\"amplitude_max\":{\"type\":\"array\",\"description\":\"[dB]\",\"items\":{\"type\":\""
    "number\"}},\"range_max\":{\"type\":\"array\",\"description\":\"[m]\",\"items\":{\"ty"
    "pe\":\"number\"}}},\"required\":[\"angle\",\"range_min\",\"range_max\",\"amplitude"
    "_max\"]}},\"required\":[\"result\",\"filter\",\"settings\"]}"
    ,
    /* example: */
    "{\"result\":{\"amplitude_mean\":[5.347396,5.263155,5.224655,5.179926,5.097"
    "782,5.116479,5.051756,4.983473,5.007885,5.002441,4.982],\"range_mean\":["
    "0.1105621,0.1079564,0.1087088,0.1067261,0.1054582,0.1090412,0.102871,0"
    ".1019044,0.1051523,0.1058445,0.1031261],\"angle\":[14.9,15.0,15.1,15.2,1"
    "5.3,15.4,15.5,15.6,15.7,15.8,15.9],\"timestamp\":[408.4441,411.4443],\"am"
    "plitude_sigma\":[0.4272844,0.4298479,0.4236816,0.4283583,0.4362353,0.43"
    "15141,0.4373984,0.4472798,0.4346001,0.4345487,0.4540681],\"amplitude_of"
    "fset\":[1.9,1.9],\"range_sigma\":[0.01869652,0.02151435,0.01747969,0.0191"
    "8765,0.01945776,0.01934862,0.01955329,0.02225589,0.02229977,0.01899122"
    ",0.02009433]},\"settings\":{\"amplitude\":{\"additive_value\":1.0,\"sigma_fac"
    "tor\":4},\"range\":{\"additive_value\":0.1,\"sigma_factor\":8}},\"filter\":{\"ra"
    "nge_min\":[-0.208,-0.21,-0.212,-0.214,-0.216,-0.218,-0.219,-0.221,-0.22"
    "3,-0.225,-0.227],\"angle\":[14.9,15.0,15.1,15.2,15.3,15.4,15.5,15.6,15.7"
    ",15.8,15.9],\"amplitude_max\":[8.04,8.01,7.99,7.96,7.93,7.9,7.88,7.85,7."
    "83,7.8,7.78],\"range_max\":[0.424,0.425,0.426,0.427,0.428,0.428,0.429,0."
    "43,0.431,0.431,0.432]}}"
};

// Correction parameters for window glass echoes
const MetaDataItemInfo RDB_RIEGL_WINDOW_ECHO_CORRECTION = {
    /* name        */ "riegl.window_echo_correction",
    /* title       */ "Window Echo Correction",
    /* description */ "Correction parameters for window glass echoes",
    /* status      */ RDB_STATUS_OPTIONAL,

    /* schema: */
    "{\"type\":\"object\",\"title\":\"Window Echo Correction\",\"$schema\":\"http://js"
    "on-schema.org/draft-04/schema#\",\"description\":\"Correction parameters "
    "for window glass echoes\",\"properties\":{\"slices\":{\"type\":\"array\",\"items"
    "\":{\"type\":\"object\",\"properties\":{\"table\":{\"type\":\"array\",\"items\":{\"typ"
    "e\":\"array\",\"items\":{\"type\":\"array\",\"items\":{\"type\":\"number\",\"descripti"
    "on\":\"Table cell (item 0: amplitude in dB, 1: range in m, 2: "
    "flags)\"},\"maxItems\":3,\"minItems\":3,\"description\":\"Table column (= "
    "range axis)\"},\"minItems\":1,\"description\":\"Table row (= amplitude "
    "axis)\"},\"minItems\":1,\"description\":\"Correction table (dimension "
    "defined by the 'amplitude' and 'range' "
    "objects)\"},\"amplitude\":{\"type\":\"number\",\"description\":\"Window echo "
    "amplitude of slice in "
    "dB\"}},\"required\":[\"amplitude\",\"table\"],\"description\":\"Window echo "
    "correction parameter slice\"}},\"amplitude\":{\"type\":\"object\",\"properties"
    "\":{\"entries\":{\"type\":\"integer\",\"minimum\":1,\"description\":\"Number of "
    "amplitude entries\"},\"minimum\":{\"type\":\"number\",\"minimum\":0.0,\"descript"
    "ion\":\"Minimum amplitude in "
    "dB\"},\"maximum\":{\"type\":\"number\",\"minimum\":0.0,\"description\":\"Maximum "
    "amplitude in dB\"}},\"required\":[\"minimum\",\"maximum\",\"entries\"],\"descrip"
    "tion\":\"Amplitude axis of correction table\"},\"range\":{\"type\":\"object\",\""
    "properties\":{\"entries\":{\"type\":\"integer\",\"minimum\":1,\"description\":\"Nu"
    "mber of range entries\"},\"minimum\":{\"type\":\"number\",\"maximum\":2.0,\"mini"
    "mum\":-2.0,\"description\":\"Minimum range in m\"},\"maximum\":{\"type\":\"numbe"
    "r\",\"maximum\":2.0,\"minimum\":-2.0,\"description\":\"Maximum range in "
    "m\"}},\"required\":[\"minimum\",\"maximum\",\"entries\"],\"description\":\"Range "
    "axis of correction table\"}},\"required\":[\"amplitude\",\"range\",\"slices\"]}"
    ,
    /* example: */
    "{\"slices\":[{\"table\":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]],\"amplitude\""
    ":1.5},{\"table\":[[[6.23,0.3535,1]],[[5.54,0.72375,1]]],\"amplitude\":2.0}"
    "],\"amplitude\":{\"entries\":128,\"minimum\":2,\"maximum\":20},\"range\":{\"entri"
    "es\":128,\"minimum\":-1.5060822940732335,\"maximum\":1.5060822940732335}}"
};

// Table of all meta data item details records
const MetaDataItemInfo* const RDB_META_DATA_ITEMS[] = {
    &RDB_RIEGL_ANGULAR_NOTCH_FILTER,
    &RDB_RIEGL_ATMOSPHERE,
    &RDB_RIEGL_BEAM_GEOMETRY,
    &RDB_RIEGL_CONTROL_OBJECT_CATALOG,
    &RDB_RIEGL_CONTROL_OBJECT_REFERENCE_FILE,
    &RDB_RIEGL_DETECTION_PROBABILITY,
    &RDB_RIEGL_DEVICE,
    &RDB_RIEGL_DEVICE_GEOMETRY,
    &RDB_RIEGL_DEVICE_GEOMETRY_PASSIVE_CHANNEL,
    &RDB_RIEGL_DEVICE_OUTPUT_LIMITS,
    &RDB_RIEGL_DEVICES,
    &RDB_RIEGL_DYNTRIG,
    &RDB_RIEGL_ECHO_INFO,
    &RDB_RIEGL_EXPONENTIAL_DECOMPOSITION,
    &RDB_RIEGL_GAUSSIAN_DECOMPOSITION,
    &RDB_RIEGL_GEO_TAG,
    &RDB_RIEGL_GEOMETRIC_SCALE_FACTOR,
    &RDB_RIEGL_GEOREFERENCING_PARAMETERS,
    &RDB_RIEGL_ITEM_NAMES,
    &RDB_RIEGL_LICENSES,
    &RDB_RIEGL_MTA_SETTINGS,
    &RDB_RIEGL_NEAR_RANGE_CORRECTION,
    &RDB_RIEGL_NOISE_ESTIMATES,
    &RDB_RIEGL_NOTCH_FILTER,
    &RDB_RIEGL_PIXEL_INFO,
    &RDB_RIEGL_PLANE_PATCH_MATCHING,
    &RDB_RIEGL_PLANE_PATCH_STATISTICS,
    &RDB_RIEGL_PLANE_SLOPE_CLASS_INFO,
    &RDB_RIEGL_POINT_ATTRIBUTE_GROUPS,
    &RDB_RIEGL_POINTCLOUD_INFO,
    &RDB_RIEGL_POSE_ESTIMATION,
    &RDB_RIEGL_POSE_SENSORS,
    &RDB_RIEGL_PULSE_POSITION_MODULATION,
    &RDB_RIEGL_RANGE_STATISTICS,
    &RDB_RIEGL_RECEIVER_INTERNALS,
    &RDB_RIEGL_REFLECTANCE_CALCULATION,
    &RDB_RIEGL_REFLECTANCE_CORRECTION,
    &RDB_RIEGL_SCAN_PATTERN,
    &RDB_RIEGL_SHOT_INFO,
    &RDB_RIEGL_STORED_FILTERS,
    &RDB_RIEGL_SYSTEM_DESCRIPTION,
    &RDB_RIEGL_TEMPERATURE_CALCULATION,
    &RDB_RIEGL_TIME_BASE,
    &RDB_RIEGL_TRAJECTORY_INFO,
    &RDB_RIEGL_TTIP_CONFIGURATION,
    &RDB_RIEGL_VERTEX_INFO,
    &RDB_RIEGL_VOXEL_INFO,
    &RDB_RIEGL_WAVEFORM_AVERAGING_SETTINGS,
    &RDB_RIEGL_WAVEFORM_INFO,
    &RDB_RIEGL_WAVEFORM_SETTINGS,
    &RDB_RIEGL_WINDOW_ANALYSIS,
    &RDB_RIEGL_WINDOW_ECHO_CORRECTION
};
const std::size_t RDB_META_DATA_ITEM_COUNT(
    sizeof(RDB_META_DATA_ITEMS) / sizeof(RDB_META_DATA_ITEMS[0])
);
const std::vector<const MetaDataItemInfo*> RDB_META_DATA_ITEMS_VECTOR(
    RDB_META_DATA_ITEMS, RDB_META_DATA_ITEMS + RDB_META_DATA_ITEM_COUNT
);

}}} // namespace riegl::rdb::pointcloud

#endif // RDB_354CFFB3_BDAA_4E38_98C8_9C09D0C0AD87
